("\"encryption\" features from the preference panel" "\"encryptie\"functies van het voorkeurenpaneel")
("(Re)Build autocompletion index" "Maak auto-aanvullings index")
("GNU" "GNU")
("LaTeX" "LaTeX")
("TeX" "TeX")
("a modifier" "A veranderaar")
("a series" "a reeks")
("a.C.M. computing class" "a.C.M. rekenklasse")
("a.M.S. subject class" "a.M.S. onderwerpklasse")
("abbreviated authors" "afgekorte auteurs")
("abbreviation" "afkorting")
("about" "over")
("about menu" "over menu")
("above" "boven")
("abbreviated authors" "afgekorte auteurs")
("abstract" "samenvatting")
("accent" "accent")
("accent above" "accent hierboven")
("accent below" "accent hieronder")
("accept" "accepteer")
("accept all scripts" "accepteer alle scripts")
("accept during this pass" "accepteer voor deze ronde")
("accept no scripts" "accepteer geen scripts")
("accept script" "accepteer script")
("acknowledge" "bedank")
("acknowledgment" "dankwoord")
("acknowledgments" "erkenningen")
("acronym" "acronym")
("action" "aktie")
("activate" "aktiveer")
("activate hidden" "aktiveer en verberg")
("activate once" "aktiveer eenmalig")
("activation" "aktivering")
("active link types" "actieve linktypen")
("acute" "naar rechts")
("add" "toevoegen")
("add abstract information" "samenvattingsinformatie toevoegen")
("add author information" "auteurinformatie toevoegen")
("add branch after" "tak hierna toevoegen")
("add branch before" "tak hiervoor toevoegen")
("add other package" "ander pakket toevoegen")
("add package" "pakket toevoegen")
("add remote ssh connection" "ssh-verbinding toevoegen")
("add style package" "stijlpakket toevoegen")
("add switch after" "schakelaar hierna toevoegen")
("add switch before" "schakelaar hiervoor toevoegen")
("add title information" "titelinformatie toevoegen")
("add to custom colors" "toevoegen aan kleurenselectie")
("addition" "optelling")
("address" "adres")
("address block" "adres blok")
("adjust" "aanpassen")
("adjust limits" "limieten aanpassen")
("advanced" "geavanceerd")
("advanced font customization" "geavanceerde lettertypeaanpassing")
("advanced layout features" "geavanceerde pagina-opmaak")
("affiliation" "aansluiting")
("after" "na")
("albanian" "albanees")
("algorithm" "algoritme")
("algorithms" "algoritmen")
("align cell to the bottom" "plaats inhoud cel aan de benedenkant")
("align cell to the decimal comma" "plaats decimale komma's onder elkaar")
("align cell to the decimal dot" "plaats decimale punten onder elkaar")
("align cell to the left" "plaats inhoud cel aan de linkerkant")
("align cell to the right" "plaats inhoud cel aan de rechterkant")
("align cell to the top" "plaats inhoud cel aan de bovenkant")
("align table at axis" "plaats tabel op de as")
("align table at base of left column" "plaats tabel op richtlijn van meest linkse kolom")
("align table at base of middle column" "plaats tabel op richtlijn van middelste kolom")
("align table at base of origin column" "plaats tabel op richtlijn van oorsprong-kolom")
("align table at base of right column" "plaats tabel op richtlijn van meest rechtse kolom")
("align table at fraction bar height" "plaats tabel op hoogte van de breukstreep")
("align table at the base of bottom row" "plaats tabel op richtlijn van laagste rij")
("align table at the base of middle row" "plaats tabel op richtlijn van middelste rij")
("align table at the base of origin row" "plaats tabel op de richtlijn van oorsprong-rij")
("align table at the base of top row" "plaats tabel op richtlijn van hoogste rij")
("align table at the bottom" "plaats tabel aan de benedenkant")
("align table at the center" "plaats tabel in het vertikale midden")
("align table at the horizontal center" "plaats tabel in het horizontale midden")
("align table at the left" "plaats tabel aan de linkerkant")
("align table at the top" "plaats tabel aan de bovenkant")
("align table to the right" "plaats tabel aan de rechterkant")
("align text to the left" "lijn tekst naar links uit")
("align text to the right" "lijn tekst naar rechts uit")
("aligned" "gericht")
("alignment" "plaatsing")
("alignment of balloon" "plaatsing van de ballon")
("all" "alles")
("all cells" "alle cellen")
("all data attached to this identity will be lost" "alle gegevens verbonden aan deze identiteit zullen verloren gaan")
("all saved passphrases will be lost forever" "alle opgeslagen wachtzinnen zullen voor altijd verloren gaan")
("allow" "sta toe")
("allow for macro definitions in preamble" "sta macro definities in preambule toe")
("allow multiple spaces" "sta meerdere spaties toe")
("allow spurious spaces" "sta onnodige spaties toe")
("allowed extension" "toegestane verlenging")
("allowed page height extension" "toegestane extra paginahoogte")
("allowed page height reduction" "toegestane paginahoogtevermindering")
("allowed positions" "toegestane posities")
("allowed positions of floating object" "toegestane posities van zwevend objekt")
("allowed reduction" "toegestane reduktie")
("alpha release" "alpha versie")
("alpha transparency" "alfatransparantie")
("also on paper" "ook op papier")
("alt key" "alt toets")
("alter" "wijzig")
("alternate" "alternatieve")
("alternate except here" "wissel af behalve hier")
("alternate from here on" "wissel af vanaf hier")
("alternate only here" "wissel alleen hier af")
("alternate until here" "wissel af tot hier")
("alternative colors" "alternatieve kleuren")
("alternative specification" "alternatieve specificatie")
("always" "altijd")
("american" "amerikaans")
("amplified" "versterkt")
("anchor" "anker")
("ancient" "oude")
("and" "en")
("and perform casual settings from the \"Encryption\" tab" "en voer losse instellingen uit vanaf het tabblad \"Codering\"")
("angle" "hoek")
("angular" "hoekig")
("animate" "animeren")
("animate folding" "animeer het opvouwen")
("animate object" "animeer objekt")
("animate objects" "animeer objekten")
("animate unfolding" "animeer het ontvouwen")
("animated" "geanimeerd")
("animation" "animatie")
("animation toolbar" "werkbalk voor animaties")
("annotate" "annoteren")
("annote" "annoteren")
("answer" "antwoord")
("answer field" "antwoordveld")
("answer to question" "antwoord op vraag")
("answers" "antwoorden")
("answers only" "alleen antwoorden")
("any" "elke")
("appear" "verschijnen")
("appendix" "appendix")
("apply" "gebruiken")
("apply macro" "gebruik macro")
("apply macro once" "gebruik macro eenmalig")
("approximate" "benader")
("april" "april")
("arab" "arabisch")
("arc" "boog")
("arc cosine" "boogcosinus")
("arc sine" "boogsinus")
("arc tangent" "boogtangens")
("arch series" "arch reeks")
("archaic" "archaisch")
("architecture" "opzet")
("are you sure you want to delete collected public keys" "weet u zeker dat u verzamelde openbare sleutels wilt verwijderen")
("are you sure you want to delete selected public keys" "weet u zeker dat u geselecteerde openbare sleutels wilt verwijderen")
("are you sure you want to delete selected secret keys" "weet u zeker dat u geselecteerde geheime sleutels wilt verwijderen")
("are you sure you want to destroy the wallet" "weet je zeker dat je de portemonnee wilt vernietigen")
("argument" "argument")
("arithmetic" "arithmetiek")
("armenian" "armeens")
("arrow" "pijl")
("arrows" "pijlen")
("art Pen" "kunstpen")
("art frame" "kunstlijst")
("article" "artikel")
("arxiv category" "arxiv-categorie")
("as on paper" "zoals op het papier")
("as visual grid" "als visueel raster")
("aspect" "aspekt")
("assign" "verander")
("at fraction bar height" "op hoogte breukstreep")
("at the baseline" "op de richtlijn")
("at the bottom" "onder")
("at the left" "links")
("at the middle" "in het midden")
("at the right" "rechts")
("at the top" "boven")
("attach" "koppel")
("attach buffer to which project" "koppel buffer aan welk projekt")
("attach master" "koppel aan meester")
("attach master file for project" "hoofdbestand om aan vast te koppelen")
("attached" "bijgevoegd")
("august" "augustus")
("author" "auteur")
("authorize" "keur goed")
("auto" "auto")
("auto-save file" "bestand automatisch opslaan")
("automate" "automatiseren")
("automatic" "automatisch")
("automatic brackets" "automatische haken")
("automatic content generation" "automatische inhoud generatie")
("automatic program brackets" "automatische haken in programma's")
("automatic quotes" "automatische aanhalingstekens")
("automatically close brackets" "sluit haakjes automatisch")
("automatically generated content" "automatisch aangemaakte inhoud")
("automatically import bibliographies when opening files" "importeer bibliografie automatisch bij het openen van bestanden")
("automatically open this console on errors" "open deze console automatisch bij fouten")
("automatically open this console on warnings" "open deze console automatisch bij waarschuwingen")
("automatically remember all passphrases in the wallet" "onthoud automatisch alle wachtzinnen in de portemonnee")
("automatically save" "sla automatisch op")
("autosave" "automatisch opslaan")
("avoid spurious spaces" "vermijd onnodige spaties")
("axiom" "axioma")
("axioms" "axioma's")
("axis" "as")
("b series" "b reeks")
("back" "terug")
("background" "achtergrond")
("background color" "achtergrond kleur")
("background evaluations" "evaluaties op de achtergrond")
("background pattern" "achtergrondpatroon")
("background picture" "achtergrondafbeelding")
("background picture selector" "achtergrondafbeelding kiezen")
("backtrace errors" "fouten traceren")
("backward replace" "achteruit vervangen")
("backward search" "achteruit zoeken")
("bad data format" "verkeerd bestandsformaat")
("balloon" "ballon")
("bar" "streep")
("bard" "bardisch")
("base" "basis")
("base level" "basisniveau")
("baseline" "richtlijn")
("bashkirian" "bashkirisch")
("basic" "basis")
("basic colors" "basiskleuren")
("basic communication using pipes" "elementaire kommunicatie over pijpen")
("basic data types" "fundamentele data types")
("basic types" "basis types")
("be useful" "help mee")
("beamer" "beamer")
("beamer formats" "beamer formaten")
("beamer theme" "beamer thema")
("become a TeXmacs developer" "word een TeXmacs ontwikkelaar")
("before" "voor")
("begin" "begin")
("below" "onder")
("bench" "timen")
("bend bottom" "buig bodem")
("bend corner" "buig hoek")
("bend diagonal" "buig diagonaal")
("bend in" "buig inwaards")
("bend out" "buig uitwaards")
("beta release" "beta versie")
("bezier" "bezier")
("bibTeX command" "bibTeX commando")
("bibliography" "bibliografie")
("bibliography file" "bibliografie bestand")
("bibliography style" "bibliografie stijl")
("bidirectional" "twee richtingen uit")
("big" "grote")
("big environment box" "grote omgevingsrechthoek")
("big figure" "groot figuur")
("big focus" "grote focus")
("big operator" "grote operator")
("big skip" "grote sprong")
("big table" "grote tabel")
("binary operation" "binaire operatie")
("binary operator" "binaire operator")
("binary relation" "binaire relatie")
("bitmap resolution (dpi)" "bitmap resolutie (dpi)")
("black" "zwart")
("black floral I" "zwarte bloemen I")
("black floral II" "zwarte bloemen II")
("blackboard" "schoolbord")
("blackboard bold" "schoolbord vet")
("blackboard embold" "schoolbord vet")
("blackboard math" "schoolbord wiskunde")
("blackletter" "zwarte letter")
("blank column" "lege kolom")
("blank row" "lege rij")
("block" "blok")
("block content" "blokinhoud")
("block of code" "codeblok")
("blue" "blauw")
("bluish" "blauwachtig")
("blur" "vervagen")
("blur radius" "vervagingstraal")
("body" "lichaam")
("body color" "lichaamskleur")
("bold" "vet")
("book" "boek")
("booklet" "boekje")
("border" "rand")
("boring-white" "saai wit")
("both" "beide")
("both versions" "beide versies")
("bothlined" "gestreept")
("bottom" "bodem")
("bottom baseline" "onderste richtlijn")
("bottom border" "onderrand")
("bottom cell border" "onderrand cel")
("bottom cell padding" "ruimte onderkant cel")
("bottom center" "middenonder")
("bottom left" "linksonder")
("bottom margin" "onderrand")
("bottom padding" "ruimte beneden")
("bottom right" "rechtsonder")
("bottom table border" "onderrand tabel")
("bottom table padding" "ruimte onderkant tabel")
("bottom tools" "onderste gereedschappen")
("box" "rechthoek")
("branch" "tak")
("break" "afbreken")
("breaking" "afbraak")
("breve" "breve")
("bright" "licht")
("british" "brits")
("broken citations" "verbroken citaten")
("broken references" "verbroken referenties")
("broken white" "gebroken wit")
("brown" "bruin")
("browse" "surfen")
("browse back" "blader terug")
("browse forward" "blader vooruit")
("browse modules documentation" "blader door de moduledocumentatie")
("browse symbols documentation" "documentatie met symbolen doorbladeren")
("browse web" "surf over het web")
("browser" "surfprogramma")
("buffer" "buffer")
("buffer in this window" "buffer in dit venster")
("buffer management" "bufferbeheer")
("buffer must be on disk" "buffer moet op schijf staan")
("buffer must have a name" "buffer moet een naam hebben")
("build buffer" "buffer opbouwen")
("build buffer in" "buffer opbouwen in")
("build directory" "map opbouwen")
("build directory in" "map opbouwen in")
("build link pages" "stel linkpagina's samen")
("build-all" "alles opbouwen")
("bulgarian" "bulgaars")
("bullet" "rondje")
("bullets" "rondjes")
("bump" "springen")
("busy" "bezig")
("by" "door")
("by typing" "ook verkrijgen via de toetsenkombinatie")
("bytes free" "bytes vrij")
("bytes used" "bytes gebruikt")
("cJK" "cJK")
("cJK spacing" "cJK spatiëring")
("cSS stylesheet" "CSS stijlblad")
("calculus" "differentiaalrekening")
("calligraphic" "kaligrafisch")
("cancel" "annuleer")
("cancelled" "geannuleerd")
("cannot download directory to file" "kan map niet naar bestand downloaden")
("cannot rename across different servers" "hernoemen niet mogelijk over verschillende servers")
("cannot upload directory to file" "kan map niet naar bestand uploaden")
("caps-lock key" "caps-lock toets")
("caption" "bijschrift")
("cartesian" "cartesiaans")
("cartoon" "cartoon")
("carved wood" "gesneden hout")
("case" "kies")
("case-insensitive search" "hoofdletter-ongevoelig zoeken")
("categories" "categorieën")
("category" "categorie")
("cell" "cel")
("cell background color" "achtergrondkleur cel")
("cell border" "rand cel")
("cell color" "celkleur")
("cell height" "hoogte van de cel")
("cell operation mode" "celmodus")
("cell properties" "celeigenschappen")
("cell span" "celbereik")
("cell width" "breedte van de cel")
("cells" "cellen")
("center" "midden")
("center baseline" "centrale richtlijn")
("center text" "centreer tekst")
("centered" "gecentreerd")
("centered block" "gencetreerd blok")
("centered programs" "gecentreerde programma's")
("centered tabular" "gecentreerde tabel")
("chalk" "krijt")
("change border of cell" "verander celrand")
("change cell operation mode" "verander celmodus")
("change default unit" "standaardeenheid wijzigen")
("change log" "opgave van veranderingen")
("change passphrase" "wachtzin wijzigen")
("change permissions" "machtigingen wijzigen")
("change step-size" "stapgrootte wijzigen")
("change tags" "tags wijzigen")
("change the TeXmacs preferences" "de TeXmacs-voorkeuren wijzigen")
("change the border of the table" "verander de rand van de tabel")
("change the style of mathematical formulas" "verander de stijl van wiskundige formules")
("change wallet passphrase" "wachtzin voor portemonnee wijzigen")
("changes" "veranderingen")
("chapter" "hoofdstuk")
("character compression" "tekencompressie")
("character contraction" "letterversmalling")
("character count" "aantal tekens")
("character encoding" "lettercodering")
("character expansion" "letterverbreding")
("check" "check")
("check exported Pdf files for correctness" "geëxporteerde PDF-bestanden op juistheid controleren")
("check for automatic updates" "automatisch checken voor nieuwe versies")
("check for updates" "check voor nieuwe versies")
("check text for spelling errors" "zoek spelfouten in tekst")
("checkable field" "controleerbaar veld")
("chinese" "chinees")
("choice" "keuze")
("choose background" "achtergrond kiezen")
("choose color" "kleur kiezen")
("cipher algorithm for passphrase encryption" "coderingsalgoritme voor wachtzincodering")
("circle" "cirkel")
("citation" "citatie")
("cite" "citeer")
("cite TeXmacs" "TeXmacs citeren")
("cite TeXmacs-related work" "citeer werk omtrent TeXmacs")
("cite related work" "citeer gerelateerd werk")
("class" "klasse")
("classic" "klassiek")
("classification" "classificatie")
("clean slate" "schone lei")
("clear" "wis")
("clear all fields" "alle velden wissen")
("clear local information" "lokale informatie wissen")
("clear menu" "menu wissen")
("clear selection" "wis selectie")
("clear undo history" "geschiedenis wissen")
("click Ok button twice to discard this warning" "klik tweemaal op OK om deze waarschuwing te negeren")
("client" "klant")
("clip" "clip")
("clipboard image format" "klembord plaatjesformaat")
("clipped" "afgeknot")
("clipped and magnified" "afgeknot en uitvergroot")
("clipped and resized" "afgeknot en uitgerekt")
("clone" "kloon")
("clone window" "dupliceer venster")
("close" "sluit af")
("close TeXmacs" "sluit TeXmacs")
("close animation tool" "sluit gereedschap voor animaties")
("close buffer" "sluit buffer")
("close document" "sluit document")
("close program" "programma afsluiten")
("close replace tool" "sluit gereedschap om te vervangen")
("close search tool" "sluit gereedschap om te zoeken")
("close session" "sluit sessie")
("close spell tool" "sluit spellingscontrole")
("close translations to rebuild" "sluit vertalingen om opnieuw op te bouwen")
("close window" "sluit venster")
("closed bezier" "gesloten bezierkromme")
("closed curve" "gesloten kromme")
("closed smooth" "gesloten gladde kromme")
("closed spline" "gesloten spline kromme")
("closing" "afsluiting")
("closing style" "sluitstijl")
("cluster by affiliation" "clusteren op basis van aansluiting")
("code" "code")
("collect garbage" "afval verzamelen")
("collected keys" "verzamelde sleutels")
("color" "kleur")
("color according to nesting level" "kleur volgens nestniveau")
("color of the axes" "kleur van de assen")
("color of the subunits" "kleur van de ondereenheden")
("color of the units" "kleur van de eenheden")
("colors" "kleuren")
("column" "kolom")
("column contains glued items" "kolom bevat aan elkaar gelijmde delen")
("column separation" "kolomscheiding")
("column to the left" "kolom naar links")
("column to the right" "kolom naar rechts")
("columns" "kolommen")
("columns separation" "kolommen scheiding")
("command" "commando")
("commit" "bevestigen")
("commit file" "bestand bevestigen")
("common" "gemeenschappelijk")
("common formats" "algemene formaten")
("commutative diagram" "commutatief diagram")
("compact" "kompakt")
("compact lists" "compacte lijsten")
("compactification" "kompaktheid")
("compactify" "maak kompakt")
("compare" "vergelijken")
("compare with" "vergelijken met")
("compatibility with other formats" "uitwisselbaarheid met andere formaten")
("compile article" "stel artikel samen")
("compile book" "stel boek samen")
("compile buffer" "compileer buffer")
("compile project" "compileer projekt")
("complete bibliographic reference" "volledige bibliografische referentie")
("completion" "aanvulling")
("complex" "complex")
("complex actions" "complexe acties")
("compose" "samenstellen")
("compound" "samenstelling")
("compress" "comprimeren")
("compress into toolbar" "comprimeren in werkbalk")
("compressed" "gecomprimeerd")
("conceal" "verbergen")
("concrete" "concreet")
("condensed" "nauw")
("condition" "voorwaarde")
("conference" "conferentie")
("configuration" "configuratie")
("configure look and feel" "uiterlijk configureren")
("confirm collected public key deletion" "bevestig de verwijdering van de ingezamelde openbare sleutel")
("confirm database entry" "bevestig database item")
("confirm entry" "bevestig item")
("confirm public key deletion" "bevestig de verwijdering van de openbare sleutel")
("confirm secret key deletion" "bevestig de verwijdering van de geheime sleutel")
("confirm selected database entries" "bevestig geselecteerde database-ingangen")
("confirm selected entries" "bevestig geselecteerde items")
("confirm wallet destruction" "bevestig de vernietiging van de portemonnee")
("conjecture" "vermoeden")
("conjectures" "vermoedens")
("conservative conversion between LaTeX and TeXmacs" "conservatieve conversie tussen LaTeX en TeXmacs")
("conservative conversion options" "conservatieve conversie-opties")
("consoles" "consoles")
("constants" "constanten")
("constellation" "constellatie")
("contact" "kontakt")
("content" "inhoud")
("content tag" "inhoudelijk")
("context aids" "context indicaties")
("context dependent icons" "context afhankelijke iconen")
("contextual hints" "contextuele hints")
("continuation of" "vervolg van")
("continue" "doorgaan")
("continued fraction" "kettingbreuk")
("contour" "contour")
("contract logarithms" "logarithmes inkrimpen")
("contribute" "doe mee")
("control flow" "besturingsstroom")
("control the evaluation of expressions" "kontroleer de evaluatie van expressies")
("convention" "conventie")
("conventions" "conventies")
("convert" "converteren")
("converters" "converters")
("converters to other data formats" "converters voor andere formaten")
("convertible" "converteerbaar")
("copy" "kopiëer")
("copy new objects to all frames" "nieuwe objecten naar alle frames kopiëren")
("copy new objects to previous frames" "nieuwe objecten naar vorige frames kopiëren")
("copy new objects to subsequent frames" "nieuwe objecten naar volgende frames kopiëren")
("copy text" "kopiëer tekst")
("copy to" "kopiëer naar")
("copy to all frames after" "kopiëren naar alle frames na")
("copy to all frames before" "eerder naar alle frames kopiëren")
("copy to all other frames" "kopiëren naar alle andere frames")
("copying" "copiëren")
("copyright" "copyright")
("cork charset with TeX catcode definition in preamble" "Cork karakterset met TeX catcode definitie in preambule")
("cork with catcodes" "Cork met catcodes")
("corollaries" "gevolgen")
("corollary" "gevolg")
("correct" "corrigeren")
("correct all" "alles corrigeren")
("correct formula" "formule corrigeren")
("correct manually" "handmatig corrigeren")
("correct mathematical formulas" "wiskundige formules corrigeren")
("correct text" "korrigeer tekst")
("correction" "correctie")
("cosine" "cosinus")
("could not load" "kon niet laden")
("count characters" "letters tellen")
("count lines" "regels tellen")
("count words" "woorden tellen")
("course" "les")
("create a new document" "begin met een nieuw document")
("create context macro" "contextmacro maken")
("create link" "link maken")
("create preamble" "preambule maken")
("create remote account" "externe account maken")
("create remote directory" "externe map maken")
("create remote file" "extern bestand maken")
("create subprogram" "subprogramma maken")
("create subsession" "subsessie maken")
("create table macro" "tabelmacro maken")
("create web site" "website creëren")
("created new document" "nieuw document gemaakt")
("creating new account" "nieuwe account wordt aangemaakt")
("creating technical pictures" "technische afbeeldingen maken")
("croatian" "Kroatisch")
("crop" "afsnijden")
("crop marks" "snijtekens")
("cross" "kruis")
("crossed boxes" "aangekruiste vakjes")
("crossed circles" "aangekruiste cirkels")
("current graphical mode" "huidige grafische modus")
("current user version" "huidige gebruikersversie")
("current version" "huidige versie")
("cursor" "cursor")
("cursors" "cursor")
("curve" "kromme")
("curve intersections" "snijpunten van krommes")
("curve points" "punten op krommes")
("custom colors" "kleurenselectie")
("custom tab" "gepersonnaliseerde tabulering")
("customizations" "aanpassingen")
("customize macro" "macro aanpassen")
("customizing TeXmacs" "personaliseer TeXmacs")
("customizing and extending the user interface" "aanpassen en uitbreiden van de gebruikersinterface")
("customizing the TeXmacs styles" "personaliseer de TeXmacs stijlen")
("custum tab" "gepersonnaliseerde tabulering")
("cut" "wis")
("cut text" "wis tekst")
("cut to" "wis naar")
("cyan" "cyaan")
("cypriot" "cypriotisch")
("cyrillic" "cyrillisch")
("cyrillic input method" "cyrillisch via toetsenbord")
("cyrillic italic right" "cyrillisch scheef maar recht")
("czech" "tsjechisch")
("dancers" "dansers")
("danish" "deens")
("dark" "donker")
("dark grey" "donkergrijs")
("dark-vador" "dark vador")
("dash" "streep")
("dashes" "strepen")
("data" "data")
("data conversion" "gegevens omzetten")
("data format" "gegevensformaat")
("database entry" "database item")
("database tool" "gereedschap voor databases")
("database toolbar" "werkbalk voor databases")
("date" "datum")
("deactivate" "disaktiveer")
("deactivate once" "disaktiveer eenmalig")
("deactivate table" "deaktiveer tabel")
("dead" "dood")
("debug" "debuggen")
("debugging console" "console voor foutopsporing")
("debugging tool" "gereedschap voor foutopsporing")
("december" "december")
("decimal comma" "decimale komma")
("decimal dot" "decimale punt")
("decomposed" "afzonderlijk")
("decorate atoms" "versier atomen")
("decorated" "versierd")
("decorated wood" "versierd hout")
("decorative" "decoratief")
("decrease size" "verkleinen")
("decrypt" "decoderen")
("decrypted" "gedecodeerd")
("decryption" "decodering")
("default" "vooringesteld")
("default padding" "gebruik standaard ruimte")
("default size" "standaardgrootte")
("definition" "definitie")
("definitions" "definities")
("degrade" "degraderen")
("degraded" "gedegradeerd")
("delete" "verwijder")
("delete column" "wis kolom")
("delete documentation cache" "documentatiecache verwijderen")
("delete entries" "items verwijderen")
("delete link" "link verwijderen")
("delete row" "wis rij")
("delete selected entries in wallet" "geselecteerde items in portefeuille verwijderen")
("delete user identity" "gebruikersidentiteit verwijderen")
("deleted" "verwijderd")
("denominator" "noemer")
("describe" "beschrijven")
("describe tag" "beschrijf tag")
("description" "beschrijving")
("destination" "bestemming")
("destroy" "vernietigen")
("detach" "ontkoppel")
("detach master" "loskoppelen van meester")
("detailed" "gedetailleerd")
("detailed menus" "gedetailleerde menus")
("details in menus" "details in de menus")
("determinant" "determinant")
("determine margins from text width" "marges bepalen uit tekstbreedte")
("devangari" "devangarisch")
("developer" "ontwikkelen")
("developer tool" "gereedschap voor ontwikkelaars")
("developers guide" "gids voor ontwikkelaars")
("device" "apparaat")
("diamond" "diamant")
("differentiate" "afgeleide")
("digital" "digitaal")
("dilate" "uitzetten")
("direction of progression" "voortgangsrichting")
("direction of translation" "translatierichting")
("directory" "map")
("disable" "uit")
("disable coloring on paper" "kleuren op papier uitschakelen")
("disable encryption" "codering uitschakelen")
("disable first indentation" "begin inspringen uit")
("disable first indentation after" "begin inspringen uit hierna")
("disable first indentation before" "begin inspringen uit hiervoor")
("disable indentation" "inspringen uit")
("disable indentation after" "inspringen uit hierna")
("disable indentation before" "inspringen uit hiervoor")
("disable last indentation" "eind inspringen uit")
("disable last indentation after" "eind inspringen uit hierna")
("disable last indentation before" "eind inspringen uit hiervoor")
("disabled" "uitgeschakeld")
("disallow" "verbied")
("disappear" "verdwijnen")
("disk" "schijf")
("display style" "weergavestijl")
("displayed formula" "weergegeven formule")
("dissociate joined cells" "verbonden cellen dissociëren")
("distill encapsulated Pdf files" "ingekapselde PDF-bestanden destilleren")
("distort" "vervormen")
("distorted" "vervormd")
("distribute unused space" "verdeel ongebruikte ruimte")
("div" "div")
("division" "breuk")
("do not break up large formulas" "grote formules niet afbreken")
("do not remap" "niet doorsturen")
("document" "document")
("document colors" "kleuren voor document")
("document font selector" "selecteer lettertype voor document")
("document format" "documentformaat")
("document language" "taal voor document")
("document metadata" "metadata voor document")
("document page format" "pagina-indeling voor document")
("document paragraph format" "alinea-indeling voor document")
("document source tree preferences" "voorkeuren voor bronstructuur presentatie")
("document style" "document stijl")
("document styles" "document stijlen")
("document updates run" "aantal rondes voor document-updates")
("documentation" "documentatie")
("documents are trees" "documenten zijn bomen")
("documents in separate windows" "documenten in afzonderlijke vensters")
("dot" "rondje")
("dots" "rondjes")
("double stroke" "dubbele lijn")
("double the zoom factor for TeXmacs documents" "verdubbel de zoom faktor voor TeXmacs documenten")
("down" "omlaag")
("download" "haal van web")
("download file or directory" "download bestand of map")
("downwards" "naar beneden")
("dpi" "punten per duim")
("dragging" "aan het slepen")
("draw" "tekenen")
("draw graphics" "plaatje tekenen")
("draw image" "plaatje tekenen")
("draw over" "tekenen boven")
("draw over selection" "bovenop selectie tekenen")
("draw under" "tekenen onder")
("drop" "val")
("due to" "te danken aan")
("duplicate" "dubbel")
("duplicate labels" "dubbele etiketten")
("duration" "duur")
("dutch" "nederlands")
("dynamic" "dynamisch")
("dynamic libraries" "dynamische bibliotheken")
("eRROR" "fOUT")
("echelon" "echelon")
("edit" "bewerken")
("edit animation" "animatie bewerken")
("edit groups of objects" "groepen objecten bewerken")
("edit macro" "macro bewerken")
("edit macros" "macro's bewerken")
("edit object properties" "objecteigenschappen bewerken")
("edit package" "pakket bewerken")
("edit preamble" "preambule bewerken")
("edit source" "bron bewerken")
("edit source tree" "bewerk de boomstruktuur")
("edit style" "stijl bewerken")
("edit translations file" "vertaalbestand bewerken")
("editing tools" "bewerkingsgereedschap")
("education" "onderwijs")
("effect pen" "effect-pen")
("eigenvalues" "eigenwaarden")
("eigenvalues and vectors" "eigenwaarden en vectoren")
("eighth" "achtste")
("elevation" "verhoging")
("email" "email")
("embed all linked images" "alle gelinkte afbeeldingen insluiten")
("embed image" "afbeelding insluiten")
("embed this image" "deze afbeelding insluiten")
("embold" "vervet")
("emboss" "reliëf")
("emphasize" "benadruk")
("emphasize text" "benadruk tekst")
("empty box" "leeg vakje")
("enable first indentation" "begin inspringen aan")
("enable first indentation after" "begin inspringen aan hierna")
("enable first indentation before" "begin inspringen aan hiervoor")
("enable indentation" "inspringen aan")
("enable indentation after" "inspringen aan hierna")
("enable indentation before" "inspringen aan hiervoor")
("enable last indentation" "eind inspringen aan")
("enable last indentation after" "eind inspringen aan hierna")
("enable last indentation before" "eind inspringen aan hiervoor")
("enable page breaking" "pagina-afbraak inschakelen")
("enabled" "ingeschakeld")
("encl." "bijgesloten")
("encoding" "codering")
("encrypt" "coderen")
("encrypted" "gecodeerd")
("encrypted buffer" "gecodeerde buffer")
("encryption" "codering")
("encryption error" "coderingsfout")
("encryption facilities are not currently available" "coderingsfaciliteiten zijn momenteel niet beschikbaar")
("encryption facilities have not been enabled for TeXmacs" "coderingsfaciliteiten zijn niet ingeschakeld voor TeXmacs")
("end" "einde")
("enforce brackets to match" "overeenkomende haakjes afdwingen")
("english" "engels")
("engrave" "graveren")
("enter a title" "geef een titel op")
("enter data" "gegevens invoeren")
("enter graphic mode" "grafische modus openen")
("enter graphics" "plaatje invoeren")
("enter graphics mode" "naar grafische modus")
("enter new passphrase for encryption" "voer een nieuwe wachtzin in voor codering")
("enter passphrase for decryption" "wachtzin invoeren voor decodering")
("enter passphrase for identity" "wachtzin invoeren voor identiteit")
("enter title information" "titelinformatie invoeren")
("entire table" "hele tabel")
("entry" "item")
("entry type" "item type")
("entry up to date in database" "item is actueel in database")
("enumerate" "nummeren")
("enumerate|Alpha" "Letters")
("enumerate|Roman" "Romeins")
("enumerate|alpha" "letters")
("enumerate|roman" "romeins")
("enunciation" "verkondiging")
("env" "omgeving")
("environment" "omgeving")
("environment variable" "omgevingsvariabele")
("environments" "omgevingen")
("epilogue" "nawoord")
("equal" "gelijk")
("equation" "vergelijking")
("equations" "vergelijkingen")
("equivalent for" "equivalent voor")
("erode" "afslijten")
("error" "fout")
("error messages" "foutmeldingen")
("error output" "foutuitvoer")
("error status report" "statusrapport foutmeldingen")
("error: bracket does not match" "fout: haak komt niet overeen")
("error: cyclic or missing chunks detected" "fout: cyclische of ontbrekende stukken gedetecteerd")
("error: file not found" "fout: bestand niet gevonden")
("error: ghostview does not seem to be installed on your system" "fout: ghostview lijkt niet op uw systeem te zijn geïnstalleerd")
("error: one of the alternatives should be filled out" "fout: een van de alternatieven moet worden ingevuld")
("error: only one alternatives should be filled out" "fout: slechts één alternatief moet worden ingevuld")
("error: should fill out name for referencing" "fout: moet naam invullen voor verwijzing")
("error: should fill out required field" "fout: moet verplicht veld invullen")
("escape" "escape")
("esperanto" "esperanto")
("etruscan" "etruskisch")
("european numbering style" "europese nummeringsstijl")
("evaluable field" "uitvoerbaar veld")
("evaluate" "evalueer")
("evaluate above" "hierboven uitvoeren")
("evaluate all" "alles uitvoeren")
("evaluate below" "hieronder uitvoeren")
("evaluate fields" "velden uitvoeren")
("evaluate fields in order" "velden op volgorde uitvoeren")
("evaluate scheme expression" "scheme expressie uitvoeren")
("evaluate script" "script uitvoeren")
("evaluation" "evalueren")
("evaluation switch" "evaluatie schakelaar")
("evaluation tag" "evaluatie veld")
("even page" "even pagina")
("even page footer" "even pagina voet")
("even page header" "even pagina kop")
("even page left margin" "even pagina linkerrand")
("even page margin" "even pagina rand")
("even page shift" "even pagina verschuiving")
("even page text" "even pagina tekst")
("even pages" "even pagina's")
("events" "evenementen")
("exact" "exact")
("exact horizontal" "horizontaal exact")
("exact mode" "exacte modus")
("exam" "examen")
("example" "voorbeeld")
("examples" "voorbeelden")
("exclusive" "exclusief")
("exclusive or" "ofwel")
("executable" "uitvoerbaar")
("execute" "voer uit")
("execute a TeXmacs command" "TeXmacs kommando uitvoeren")
("execute system command" "systeemkommando uitvoeren")
("execution of scripts" "uitvoering van scripts")
("executive" "executief")
("exercise" "oefening")
("exercises" "oefeningen")
("exit graphics" "verlaat het plaatje")
("exit graphics mode" "verlaat de grafische modus")
("exit left" "verlaat links")
("exit right" "verlaat rechts")
("exit tag on the left" "verlaat tag naar links")
("exit tag on the right" "verlaat tag naar rechts")
("expand" "ontwikkel")
("expand TeXmacs macros with no LaTeX equivalents" "werk TeXmacs macro's zonder
LaTeX-equivalenten uit")
("expand beamer slides" "beamer slides uitwerken")
("expand inclusions" "insluitsels uitbreiden")
("expand logarithms" "logarithmes uitbreiden")
("expand trigonometric functions" "trigonometrische funkties uitbreiden")
("expand unrecognized macros" "onbekende macros uitbreiden")
("expand user-defined macros" "gebruikersmacros uitbreiden")
("expanded" "uitgebreid")
("experimental" "experimenteel")
("experimental features (to be used with care)" "experimentele functies (voorzichtig te gebruiken)")
("explain" "uitleggen")
("explained" "met uitleg")
("explanatory item" "verklarend item")
("explicit keystroke" "expliciete toetsaanslag")
("explicit margins" "expliciete marges")
("exponential" "exponentiele funktie")
("exponential functions" "exponentiële functies")
("export" "exporteer")
("export as" "exporteer als")
("export bibliographies as links" "bibliografiën als verwijzingen exporteren")
("export bibliography" "bibliografie exporteren")
("export entries in buffer" "items in buffer exporteren")
("export file" "bestand exporteren")
("export formulas as images" "formules exporteren als plaatjes")
("export mathematical formulas as MathJax" "wiskundige formules exporteren als MathJax")
("export mathematical formulas as MathML" "wiskundige formules exporteren als MathML")
("export mathematical formulas as images" "wiskundige formules exporteren als afbeeldingen")
("export selected entries" "geselecteerde items exporteer")
("export selection" "selectie exporteren")
("export selection as image" "selectie exporteren als afbeelding")
("export selections as" "selecties exporteren als")
("export sessions" "sessies exporteren")
("exported bibliographic entries" "geëxporteerde bibliografische gegevens")
("exported bibliographic references" "geëxporteerde bibliografische referenties")
("extend" "uitbreiden")
("extend or normal" "'extend' of 'normal'")
("extend table to full paragraph width" "tabel uitbreiden tot volledige alineabreedte")
("extended" "verbreed")
("extensible left arrow" "uitbreidbare linkerpijl")
("extensible right arrow" "uitbreidbare rechterpijl")
("extern" "extern")
("extern " "extern")
("external" "extern")
("extra" "extra")
("extra branch" "extra tak")
("extra interline space" "extra ruimte tussen regels")
("extra name" "extra naam")
("extract" "extractie")
("extract format" "haal formaat eruit")
("extract style file" "extractie van stijlbestand")
("extract style package" "extractie van stijlpakket")
("factor" "factor")
("fade" "vervagen")
("fade in" "verscherpen")
("fade out" "vervagen")
("family" "familie")
("fast" "snel")
("fast decrease" "snelle afname")
("fast environments" "snelle omgevingen")
("fast increase" "snelle toename")
("february" "februari")
("field reference" "veldreferentie")
("fifth" "vijfde")
("figure" "figuur")
("figures" "figuren")
("file" "bestand")
("file name" "bestandsnaam")
("file not found" "bestand niet gevonden")
("file saved" "bestand opgeslagen")
("fill color" "vulkleur")
("fill out" "invullen")
("filter" "filter")
("find file" "bestand zoeken")
("find next match" "vind volgende treffer")
("find text" "vind tekst")
("finished collecting symbols documentation" "klaar met verzameling van documentatie over symbolen")
("finnish" "fins")
("first" "eerste")
("first chunk" "eerste stuk")
("first contact" "eerste kontakt")
("first difference" "eerste verschil")
("first error" "eerste fout")
("first field" "eerste veld")
("first indentation" "eerste inspringing")
("first item" "eerste element")
("first occurrence" "eerste treffer")
("first page" "eerste pagina")
("first similar" "eerste soortgelijke")
("first start" "eerste start")
("fit" "aanpassen")
("fit to height" "passend voor de hoogte")
("fit to screen" "passend voor scherm")
("fit to screen width" "passend voor schermbreedte")
("fit to width" "passend voor de breedte")
("five columns" "vijf kolommen")
("fix broken citations" "verbroken citaten repareren")
("fix broken references" "verbroken referenties repareren")
("fix duplicate labels" "dubbele etiketten repareren")
("fixed" "stil")
("flag is off" "vlag is uit")
("flag is on" "vlag is aan")
("flat" "plat")
("flatten" "flatten")
("flexibility" "flexibiliteit")
("flexibility factor for vertical spacing" "vertikale flexibiliteitsfaktor")
("floating algorithm" "zwevend algoritme")
("floating figure" "zwevend figuur")
("floating object" "zwevend objekt")
("floating phantom" "zwevend spook")
("floating table" "zwevende tabel")
("focus" "focus")
("focus dependent icons" "focusafhankelijke iconen")
("fold" "vouw")
("fold all" "alles opvouwen")
("fold all fields" "alle velden opvouwen")
("fold back" "terug vouwen")
("fold input field" "vouw invoerveld")
("folded" "gevouwen")
("follow external links" "volg externe links")
("follow inverse links" "volg omgekeerde links")
("font" "lettertype")
("font base size" "basis lettergrootte")
("font customization" "lettertype aanpassen")
("font dpi" "punten per duim")
("font effects" "lettertype effecten")
("font family" "familie lettertype")
("font name" "lettertype")
("font selector" "lettertype kiezen")
("font series" "lettersoort")
("font shape" "lettervorm")
("font size" "lettergrootte")
("font type" "lettertype")
("font variant" "variant lettertype")
("fonts" "lettertypes")
("footer" "voet")
("footnote" "voetnoot")
("for" "voor")
("for all" "voor alle")
("for each" "voor elk")
("force reloading of translations" "gedwongen herladen van vertalingen")
("foreground" "voorgrond")
("foreign" "buitenlands")
("format" "opmaak")
("formatted and structured output" "geformateerde en gestruktureerde uitvoer")
("formatted date" "datum met formaat")
("formatting" "formatering")
("formula" "formule")
("formula style" "formule stijl")
("forward" "vooruit")
("forward replace" "vervang vooruit")
("forward search" "zoek vooruit")
("four columns" "vier kolommen")
("four dots" "vier punten")
("fourth" "vierde")
("fraction" "breuk")
("fraktur" "fraktuur")
("framed" "omkaderd")
("framed input fields" "omkaderde invoervelden")
("framed programs" "omkaderde programma's")
("framed theorems" "omkaderde stellingen")
("framed title" "omkaderde titel")
("french" "frans")
("frequency" "frequentie")
("from" "van")
("from center" "vanuit het midden")
("front matter" "voorkant")
("full" "volledig")
("full author list" "volledige auteurslijst")
("full manuals" "hele handleidingen")
("full name" "volledige naam")
("full screen mode" "volledig scherm")
("function" "funktie")
("functional" "funktioneel")
("further customization" "verdere personalisatie")
("future changes" "toekomstige veranderingen")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs komt zonder enige vorm van juridische garantie")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs valt onder de ``GNU general public license''")
("gap" "gat")
("garbage collection" "rotzooi opruimen")
("gaussian" "gaussiaans")
("gaussian blur" "Gaussiaanse vervaging")
("gcd" "ggd")
("general" "algemeen")
("general architecture of TeXmacs" "algemene opbouw van TeXmacs")
("general negation" "algemene ontkenning")
("general note" "algemene noot")
("generate GnuPG key" "genereer GnuPG-sleutel")
("generated LaTeX document contains no errors" "gegenereerd LaTeX-document bevat geen fouten")
("generated field" "gegenereerd veld")
("generating font file" "Aanmaak van het lettertype")
("generic" "algemeen")
("generic input color" "generieke invoerkleur")
("generic prompt color" "generieke promptkleur")
("geometry" "meetkunde")
("georgian" "georgisch")
("german" "duits")
("get arity" "bepaal ariteit")
("get label" "bepaal label")
("get list with remote versions" "bepaal lijst met versies op afstand")
("getting started" "starten")
("global log" "globaal logboek")
("global status" "globale status")
("glossary" "symbolenlijst")
("glossary entry" "in symbolenlijst")
("glue" "lijm")
("glue decorations" "plak versiering")
("glue multiple spaces" "lijm meerdere spaties")
("glyphs" "gliefen")
("gnaw" "knagen")
("gnawed" "geknaagd")
("gnuPG command" "gnuPG-commando")
("gnuPG decryption error" "gnuPG-decodeerfout")
("gnuPG error: buffer encryption failed" "gnuPG-fout: buffercodering mislukt")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG-fout: kan geen geschikte geheime sleutel vinden om te decoderen")
("gnuPG requires name and email to have at least 5 characters" "gnuPG vereist naam en e-mailadres van minimaal 5 tekens")
("go" "naar")
("go to anchor" "ga naar anker")
("go to anchor or float" "ga naar anker of zwevend object")
("go to anchor or footnote" "ga naar anker of voetnoot")
("go to first similar tag" "ga naar eerste soortgelijke tag")
("go to float" "ga naar zwevend object")
("go to footnote" "ga naar voetnoot")
("go to last similar tag" "ga naar laatste soortgelijke tag")
("go to next similar tag" "ga naar volgende soortgelijke tag")
("go to previous similar tag" "ga naar vorige soortgelijke tag")
("go to section" "ga naar sectie")
("gothic" "gotisch")
("gradient" "kleurovergang")
("gradient selector" "kleurovergangselector")
("grain" "nauwkeurigheid")
("granite" "graniet")
("graphical effects" "grafische effecten")
("graphical interface" "grafische interface")
("graphical interface font scale" "lettertypeschaal voor grafische interface")
("graphical overlays" "grafische overlays")
("graphical slides and overlays" "grafische slides en overlays")
("graphics" "plaatje")
("graphics geometry" "grootte en plaatsing")
("graphics grids" "rooster")
("grave" "naar links")
("greater" "groter")
("greater or equal" "groter of gelijk")
("greek" "grieks")
("greek letter" "griekse letter")
("green" "groen")
("grey" "grijs")
("greyed" "grijs")
("grid" "rooster")
("grid curves" "roosterkrommen")
("grid lines" "rasterlijnen")
("grid points" "roosterpunten")
("grid-curve intersections" "snijpunten tussen rooster en krommen")
("group" "groep")
("group of objects" "groep objecten")
("group/ungroup" "groeperen/ontbinden")
("group/ungroup objects" "objecten groeperen/ontbinden")
("grouped" "gegroepeerd")
("guarantee transparent source tracking" "garandeer transparante brontracering")
("h modifier" "H veranderaar")
("half wide" "half breed")
("hand drawn" "met de hand getekend")
("handwritten" "handgeschreven")
("hanging theorems" "hangende stellingen")
("hangul" "hangul")
("happy typing" "veel plezier met het typen")
("has been aborted" "is gestopt")
("has completed its task" "heeft zijn taak volbracht")
("hat" "dakje")
("header" "kop")
("header and footer" "kop en voet")
("header bars" "kopbalken")
("headers" "koppen")
("hebrew" "hebreeuws")
("height" "hoogte")
("height is exactly the specified height" "gebruik gespecifieerde hoogte")
("height is maximum of specified height and box height" "gebruik maximum van gespecifieerde hoogte en hoogte van inhoud")
("height is minimum of specified height and box height" "gebruik minimum van gespecifieerde hoogte en hoogte van inhoud")
("height magnification" "vergroting hoogte")
("help" "help")
("help balloon" "helpballon")
("help me" "help mee")
("help us" "help ons")
("here" "hier")
("hidden" "verborgen")
("high resolution screen settings" "hoge resolutie scherminstellingen")
("high resolution settings" "hoge resolutie instellingen")
("highlight errors" "toon fouten")
("history" "geschiedenis")
("home" "thuis")
("homepage" "thuispagina")
("homoglyph substitutions" "homogliefen vervangen")
("horizontal" "horizontaal")
("horizontal alignment" "horizontale plaatsing")
("horizontal cell alignment" "horizontale plaatsing in cel")
("horizontal collapse distance" "horizontale inschuifafstand")
("horizontal ink separation" "horizontale inkt afstand")
("horizontal margins" "horizontale marges")
("horizontal padding" "horizontale vulling")
("horizontal part" "horizontaal deel")
("horizontal position" "horizontale positie")
("horizontal space" "horizontale spatie")
("horizontal table alignment" "horizontale tabelplaatsing")
("horizontally align cell to the base" "plaats inhoud cel horizontaal via richtlijn")
("horizontally center the cell" "centreer inhoud cel horizontaal")
("how much longer may pages become" "hoeveel langer mogen paginas worden")
("how much shorter may pages become" "hoeveel korter mogen paginas worden")
("huge" "enorm")
("hungarian" "hongaars")
("hybrid command" "meervoudig kommando")
("hyperbolic functions" "hyperbolische functies")
("hyperlink" "hyper-verwijzing")
("hyphenate as" "breek af als")
("hyphenation" "regelafbraak")
("ice" "ijs")
("icelandic" "ijslands")
("icon" "icoon")
("identifier" "ID")
("idle" "inactief")
("if" "als")
("if hyphenated" "als afgebroken")
("iff" "desda")
("ignore" "negeren")
("image" "plaatje")
("image links" "verbonden plaatjes")
("impact" "impact")
("implementation" "implementatie")
("import" "importeer")
("import bibliography" "bibliografie importeren")
("import database entry" "database item importeren")
("import entries in buffer" "items in buffer importeren")
("import entry" "item importeren")
("import file" "bestand importeren")
("import font" "lettertype importeren")
("import public keys from buffer" "openbare sleutels uit buffer importeren")
("import selected database entries" "geselecteerde database items importeren")
("import selected entries" "geselecteerde items importeren")
("import selections as" "selecties importeren als")
("import sessions" "sessies importeren")
("import sophisticated objects as pictures" "geavanceerde objecten als plaatjes importeren")
("imported bibliographic entries" "geïmporteerde bibliografische gegevens")
("improving the current implementation" "de huidige implementatie verbeteren")
("in popup windows" "in apparte vensters")
("inactive" "niet aktief")
("inanimated" "niet geanimeerd")
("inch" "duim")
("inches" "inch")
("include" "opnemen")
("include a document" "een document opnemen")
("include file" "bestand opnemen")
("inclusion into TeXmacs" "opname in TeXmacs")
("inclusions" "opgenomen documenten")
("incomplete entries found to be filled out" "onvolledige items gevonden die moeten worden ingevuld")
("increase size" "vergroten")
("indent" "inspringen")
("indent paragraphs" "alinea's inspringen")
("indentation" "inspringing")
("indentation flag" "inspringen")
("index" "woordenlijst")
("index entry" "in woordenlijst")
("index level" "index niveau")
("indication" "indicatie")
("inflate" "opblazen")
("informative flags" "informatieve vlaggetjes")
("initialize" "initialiseren")
("initialize wallet" "portemonnee initialiseren")
("initials" "initialen")
("ink here" "hier met inktpen schrijven")
("ink in" "schrijf geleidelijk")
("ink out" "gum geleidelijk")
("inline" "inline")
("inline args" "inline argumenten")
("inline arguments" "regel-argumenten")
("inline code" "inline code")
("inline content" "inline inhoud")
("inline formula" "inline formule")
("inline note" "kleine inline aantekening")
("inner" "binnenkant")
("inner bottom" "bodem van binnen")
("inner left" "links binnen")
("inner right" "rechts binnen")
("inner top" "top van binnen")
("input" "invoer")
("input command" "invoeropdracht")
("input field" "invoerveld")
("input mode" "invoermodus")
("input options" "invoeropties")
("insert" "invoegen")
("insert Pr" "voeg Pr in")
("insert a TeXmacs symbol" "TeXmacs symbool invoegen")
("insert a big operator" "voeg een grote operator in")
("insert a binary operation" "voeg een binaire operatie in")
("insert a binary relation" "voeg een binaire relatie in")
("insert a blackboard bold character" "voeg een vette schoolbord letter in")
("insert a bold calligraphic character" "voeg een vette kalligrafische letter in")
("insert a bold character" "voeg een vette letter in")
("insert a calligraphic character" "voeg een kalligrafische letter in")
("insert a computer program" "een computerprogramma invoegen")
("insert a condition" "voeg een voorwaarde in")
("insert a control flow instruction" "voeg een kontrolestroom-instruktie in")
("insert a fraction" "voeg een breuk in")
("insert a fraktur character" "voeg een Gotische letter in")
("insert a gap" "opening invoegen")
("insert a greek character" "voeg een griekse letter in")
("insert a large left delimiter" "voeg een grote linkerhaak in")
("insert a large right delimiter" "voeg een grote rechterhaak in")
("insert a large separator" "voeg een grote afscheider in")
("insert a left subscript" "linker subscript invoegen")
("insert a link" "maak een verwijzing")
("insert a list" "lijst invoegen")
("insert a miscellaneous symbol" "voeg een ander symbool in")
("insert a multiple choice" "meerdere keuzes invoegen")
("insert a negation" "ontkenning invoegen")
("insert a new branch" "maak een nieuwe tak")
("insert a new entry" "nieuw item invoegen")
("insert a new item" "voeg een nieuw element in")
("insert a note or a floating object" "een notitie of een zwevend object invoegen")
("insert a numerical operation" "voeg een numerieke bewerking in")
("insert a personal macro" "voeg een persoonlijke macro in")
("insert a picture" "voeg een plaatje in")
("insert a prominent piece of text" "een opvallend stuk tekst invoegen")
("insert a question" "vraag invoegen")
("insert a root" "wortel invoegen")
("insert a script" "script invoegen")
("insert a section block" "sectieblok invoegen")
("insert a square root" "voeg een wortel in")
("insert a table" "voeg een tabel in")
("insert a table or a matrix" "voeg een tabel of een matrix in")
("insert a textual operation" "voeg een tekstuele bewerking in")
("insert a textual operator" "tekstuele operator invoegen")
("insert a wide symbol above" "voeg een breed symbool hierboven in")
("insert a wide symbol below" "voeg een breed symbool hieronder in")
("insert above" "hierboven invoegen")
("insert abstract" "samenvatting invoegen")
("insert an" "maak een")
("insert an accent" "voeg een accent in")
("insert an answer" "antwoord invoegen")
("insert an arrow" "voeg een pijl in")
("insert an enunciation" "een verkondiging invoegen")
("insert an environment" "voeg een nieuwe omgeving in")
("insert an n" "maak een n")
("insert an operation on tuples" "voeg een bewerking op tuples in")
("insert annotation" "annotatie invoegen")
("insert appendix" "begin een nieuw aanhangsel")
("insert arccos" "voeg arccos in")
("insert arcs" "bogen invoegen")
("insert arcsin" "voeg arcsin in")
("insert arctan" "voeg arctan in")
("insert arg" "voeg arg in")
("insert argument" "nieuw argument")
("insert argument after" "argument invoegen hierna")
("insert argument before" "argument invoegen hiervoor")
("insert author" "voeg auteur in")
("insert automatically generated content" "voeg automatisch gegenereerd materiaal in")
("insert below" "hieronder invoegen")
("insert bibliography" "bibliografie invoegen")
("insert big contour integral" "voeg een grote cirkelintegraal in")
("insert big coproduct" "voeg een groot coprodukt in")
("insert big direct sum" "voeg een grote direkte som in")
("insert big dotted point" "voeg een grote cirkel met een punt erin in")
("insert big integral" "voeg een grote integraal in")
("insert big intersection" "voeg een grote doorsnijding in")
("insert big logical and" "voeg een grote logische en in")
("insert big logical or" "voeg een grote logische of in")
("insert big product" "voeg een groot produkt in")
("insert big square union" "voeg een grote hoekige vereniging in")
("insert big summation" "voeg een grote sommatie in")
("insert big tensor product" "voeg een groot tensor produkt in")
("insert big union" "voeg een grote vereniging in")
("insert big union sum" "voeg een grote vereningingssom in")
("insert big vertical space" "voeg grote vertikale spatie in")
("insert chapter" "begin een nieuw hoofdstuk")
("insert circles" "cirkels invoegen")
("insert closed splines" "gesloten splines invoegen")
("insert column" "voeg kolom in")
("insert column to the left" "voeg kolom naar links in")
("insert column to the right" "voeg kolom naar rechts in")
("insert copyright and license information" "copyright- en licentie-informatie invoegen")
("insert cos" "voeg cos in")
("insert cosh" "voeg cosh in")
("insert cot" "voeg cot in")
("insert coth" "voeg coth in")
("insert csc" "voeg csc in")
("insert deg" "voeg deg in")
("insert det" "voeg det in")
("insert dim" "voeg dim in")
("insert dollar" "voeg dollar in")
("insert equation" "nieuwe vergelijking")
("insert executable markup" "voeg uitvoerbaar materiaal in")
("insert exp" "voeg exp in")
("insert explanatory item" "verklarend item invoegen")
("insert field above" "veld hierboven invoegen")
("insert field below" "veld hieronder invoegen")
("insert fields" "voeg velden in")
("insert footnote" "voeg voetnoot in")
("insert formula" "voeg formule in")
("insert gcd" "voeg gcd in")
("insert hand drawn curves" "met de hand getekende krommes invoegen")
("insert hom" "voeg hom in")
("insert horizontal interword space" "voeg horizontale spatie in")
("insert image" "voeg plaatje in")
("insert inactive markup" "voer inaktief materiaal in")
("insert inf" "voeg inf in")
("insert input field above" "voeg invoerveld hierboven in")
("insert input field below" "voeg invoerveld hieronder in")
("insert ker" "voeg ker in")
("insert large delimiters" "grote haken invoegen")
("insert last name" "achternaam invoegen")
("insert left" "links invoegen")
("insert lg" "voeg lg in")
("insert lim" "voeg lim in")
("insert liminf" "voeg liminf in")
("insert limsup" "voeg limsup in")
("insert lines" "regels invoegen")
("insert ln" "voeg ln in")
("insert log" "voeg log in")
("insert macro" "voeg macro in")
("insert mathematics" "voeg wiskunde in")
("insert max" "voeg max in")
("insert medium horizontal space" "voeg gemiddelde horizontale spatie in")
("insert medium vertical space" "voeg gewone vertikale spatie in")
("insert min" "voeg min in")
("insert missing invisible operators" "ontbrekende onzichtbare operatoren invoegen")
("insert more names" "meer namen invoegen")
("insert multiple paragraphs" "meerdere alinea's invoegen")
("insert negative horizontal space" "voeg kleine negatieve spatie in")
("insert new item or number" "voeg nieuw element of nummer in")
("insert new rows or columns" "voeg nieuwe rijen of kolommen in")
("insert or delete rows or columns" "invoegen of wissen van rijen of kolommen")
("insert overlay after" "overlay invoegen hierna")
("insert overlay before" "overlay invoegen hiervoor")
("insert particle" "predicaat invoegen")
("insert plain text" "gewone tekst invoeren")
("insert points" "punten invoegen")
("insert polygons" "polygonen invoegen")
("insert right" "rechts invoegen")
("insert row" "voeg rij in")
("insert row above" "voeg rij naar boven in")
("insert row below" "voeg rij naar beneden in")
("insert sec" "voeg sec in")
("insert section" "begin een nieuwe sectie")
("insert sharp" "voeg hekje in")
("insert similar above" "soortgelijke tag hierboven invoegen")
("insert similar below" "soortgelijke tag hieronder invoegen")
("insert similar block above" "soortgelijk blok hierboven invoegen")
("insert similar block below" "soortgelijk blok hieronder invoegen")
("insert sin" "voeg sin in")
("insert sinh" "voeg sinh in")
("insert slide after" "slide hierna invoegen")
("insert slide before" "slide hiervoor invoegen")
("insert small horizontal space" "voeg kleine horizontale spatie in")
("insert small vertical space" "voeg kleine vertikale spatie in")
("insert splines" "splines invoegen")
("insert structural markup" "voeg structuur in")
("insert subscript" "subscript invoegen")
("insert subsection" "begin een nieuwe subsectie")
("insert subsubsection" "begin een nieuwe subsubsectie")
("insert subtable" "subtabel invoegen")
("insert sup" "voeg sup in")
("insert superscript" "exponent invoegen")
("insert symbol documentation" "documentatie voor symbool invoegen")
("insert tan" "voeg tan in")
("insert tanh" "voeg tanh in")
("insert template" "sjabloon invoegen")
("insert text" "tekst invoegen")
("insert text field" "voeg een tekstveld in")
("insert text field above" "tekstveld hierboven invoegen")
("insert text field below" "tekstveld hieronder invoegen")
("insert thick horizontal space" "voeg dikke horizontale spatie in")
("insert title" "voeg titel in")
("insert title after name" "titel na naam invoegen")
("insert user interface related markup" "markeringen voor de gebruikersinterface invoegen")
("insert value" "voeg waarde in")
("inserting control points" "controlepunten invoegen")
("inside mathematics" "binnen wiskunde")
("integer arithmetic" "gehele getallen")
("integrate" "integreer")
("interactive command" "interaktief kommando")
("interactive questions" "interaktieve vragen")
("intercharacter compression" "compressie tussen tekens")
("intercharacter stretching" "rekbaarheid tussen letters")
("interfacing" "nieuwe interfaces")
("interfacing TeXmacs with other systems" "TeXmacs aan andere systemen koppelen")
("interjection" "tussenwerpsel")
("interline separation" "scheiding tussen regels")
("interline space" "afstand tussen regels")
("internationalization" "internationalisering")
("interparagraph space" "afstand tussen alinea's")
("interrupt execution" "onderbreek executie")
("interrupted" "onderbroken")
("intersperse" "plaats tussen")
("introduction" "inleiding")
("invalid multi-paragraph selection" "ongeldige selectie van meerdere alinea's")
("invalid paste of text into a formula" "onmogelijk deze tekst in formule te plakken")
("invalid renaming" "ongeldige nieuwe naam")
("invert" "inverse")
("inverted breve" "omgekeerd breve accent")
("invisible" "onzichtbaar")
("invisible citation" "onzichtbare citatie")
("invisible ending" "onzichtbaar einde")
("invisible newline" "onzichtbare nieuwe regel")
("invisible opening" "onzichtbare opening")
("inwards" "naar binnen")
("irish" "iers")
("is running" "is bezig")
("is tuple" "is tupel")
("ispell does not respond" "ispell geeft geen antwoord")
("ispell is already busy" "ispell is al bezig")
("italian" "italiaans")
("italic" "schuin")
("italic right" "scheef maar recht")
("itemize" "lijst maken")
("january" "januari")
("japanese" "japans")
("join selected cells" "voeg geselecteerde cellen samen")
("journal" "tijdschrift")
("july" "juli")
("jump in" "inspringen na regelafbraak")
("june" "juni")
("junior" "junior")
("justified" "uitgelijnd")
("justify" "uitlijnen")
("justify text" "lijn tekst uit")
("keep evaluated expressions" "geëvalueerde expressies aanhouden")
("keep local" "lokaal houden")
("keep remote" "op afstand houden")
("keep track of source code" "broncode bijhouden")
("keep unfolded" "opengevouwen houden")
("key" "toets")
("key manager" "sleutelbeheerder")
("keyboard" "toetsenbord")
("keyboard configuration" "configuratie van het toetsenbord")
("keyboard equivalent" "via toetsenbord")
("keyboard modifiers" "toetsenbordwijzigingen")
("keyboard shortcut" "toetsenbordafkorting")
("keymaps" "toetsenbord")
("keys" "toetsen")
("keyword" "sleutelwoord")
("keywords" "sleutelwoorden")
("kill" "dood")
("known bugs" "bekende bugs")
("korean" "Koreaans")
("laTeX errors" "laTeX-fouten")
("label" "etiket")
("landscape" "landschap")
("language" "taal")
("laptop presentations" "laptop-presentaties")
("large" "groot")
("large brackets" "grote haken")
("large cells" "grote cellen")
("large closing bracket" "grote rechter haak")
("large delimiter" "grote haak")
("large displayed" "groot weergegeven")
("large displayed fraction" "grote weergegeven breuk")
("large opening bracket" "grote linker haak")
("large separator" "grote separator")
("large tables" "grote tabellen")
("last" "laatste")
("last check" "laatste controle")
("last difference" "laatste verschil")
("last error" "laatste fout")
("last field" "laatste veld")
("last indentation" "laatste inspringing")
("last name" "achternaam")
("last occurrence" "laatste treffer")
("last page" "laatste pagina")
("last similar" "laatste vergelijkbare")
("latex command" "latex kommando")
("latin" "latijns")
("layout" "indeling")
("lcm" "kgv")
("left" "links")
("left aligned" "links uitgelijnd")
("left arrow" "pijl naar links")
("left axis" "linkeras")
("left baseline" "linker richtlijn")
("left border" "linker rand")
("left bottom" "links onderaan")
("left cell border" "linker celrand")
("left cell padding" "ruimte linkerkant cel")
("left center" "links midden")
("left click: add point; Right click: undo" "linker muisklik: punt toevoegen; rechter muisklik: ongedaan maken")
("left click: finish; Right click: undo" "linker muisklik: voltooien; rechter muisklik: ongedaan maken")
("left click: new object" "linkermuisknop: nieuw object")
("left click: operate" "linkermuisknop: bewerk")
("left down" "naar links")
("left margin" "linker rand")
("left on even pages" "links op even pagina's")
("left padding" "ruimte links")
("left prime" "linker priem")
("left slanted" "schuin naar links")
("left subscript" "linker subscript")
("left superscript" "linker exponent")
("left surrounding" "linker omgeving")
("left table border" "linker tabelrand")
("left table padding" "ruimte linkerkant tabel")
("left top" "links bovenaan")
("left up" "links boven")
("left-right arrow" "pijl links-rechts")
("leftwards" "naar links")
("legal" "legaal")
("lemma" "hulpstelling")
("lemmas" "lemma's")
("length" "lengte")
("less" "kleiner")
("less or equal" "kleiner of gelijk")
("let the environment float" "laat de omgeving zweven")
("letter" "brief")
("license" "licentie")
("light" "dun")
("light grey" "lichtgrijs")
("limit" "limiet")
("limitations" "gebreken")
("limits" "limieten")
("line" "lijn")
("line arrows" "pijlen")
("line break" "breek regel af")
("line breaking" "regelafbraak")
("line count" "aantal regels")
("line dashes" "gestreepte lijnen")
("line portion" "lijngedeelte")
("line stretch" "regel uitrekbaarheid")
("line style" "lijnstijl")
("line width" "lijnbreedte")
("line wrapping" "lange regels afbreken")
("line wrapping inside cell" "regelafbraak in cel")
("linear 2D" "lineair 2D")
("linear algebra" "lineaire algebra")
("lines around" "lijnen rondom")
("link" "link")
("link all embedded images" "alle ingesloten afbeeldingen linken")
("link image" "plaatje linken")
("link image and copies as" "link plaatje en kopieën als")
("link image as" "link plaatje als")
("link mode" "linkmodus")
("link to URL" "link naar URL")
("linking tool" "gereedschap om te linken")
("lissajous" "lissajous")
("list" "lijst")
("list of figures" "figurenlijst")
("list of tables" "tabellenlijst")
("live" "live")
("live input-output" "live invoer-uitvoer")
("load" "laad")
("load LaTeX file" "laad LaTeX bestand")
("load TeX file" "laad TeX bestand")
("load TeXmacs file" "laad TeXmacs bestand")
("load TeXmacs style file" "laad TeXmacs stijl bestand")
("load a file" "laad een bestand")
("load buffer" "laad buffer")
("load file" "laad bestand")
("load help file" "helpbestand laden")
("load html file" "laad html bestand")
("load image" "laad plaatje")
("load in new window" "laad in nieuw venster")
("load latex file" "laad latex bestand")
("load more recent autosave file" "het nieuwere veiligheidsbestand laden")
("load remote file" "extern bestand laden")
("load tex file" "laad tex bestand")
("load verbatim file" "laad verbatim bestand")
("loaded" "geladen")
("loading" "laden")
("local entries" "lokale items")
("loci" "loci")
("locus" "locus")
("locus color" "kleur van verwijzigingen")
("locus rendering" "locus weergave")
("logarithm" "logarithme")
("logarithmic" "logaritmisch")
("logarithmic base" "logaritmische basis")
("logarithms" "logarithmes")
("logging in" "inloggen")
("logical and" "logische en")
("logical implication" "logische implicatie")
("logical not" "logische niet")
("logical or" "logische of")
("login" "inloggen")
("logout" "uitloggen")
("long" "lang")
("long macro" "lange macro")
("long text" "lange tekst")
("look and feel" "gebruikersinterface")
("look for more fonts" "zoek naar meer lettertypen")
("look up" "zoek op")
("loops" "lussen")
("lower border" "benedenrand")
("m modifier" "M veranderaar")
("macro" "macro")
("macro argument" "macro argument")
("macro definition" "macro definitie")
("macro editor" "macro editor")
("macro name" "macro naam")
("macros" "macro's")
("macros editor" "macros editor")
("magenta" "paars")
("magic" "magie")
("magnification" "vergrotingsfaktor")
("magnified" "uitvergroot")
("magnify horizontally" "horizontaal vergroten")
("magnify vertically" "verticaal vergroten")
("main" "hoofd")
("main document font" "lettertype voor document")
("main document style" "hoofddocumentstijl")
("main icon bar" "voornaamste iconen")
("main presentation style" "hoofdpresentatiestijl")
("major changes" "belangrijkste veranderingen")
("make a letter environment" "een briefomgeving maken")
("make a multi-slide presentation" "maak een presentatie met meerdere slides")
("make a page insertion" "maak een pagina invoeging")
("make a subscript" "maak een subscript")
("make a superscript" "maak een exponent")
("make acute" "maak een streepje naar rechts")
("make bar" "maak een streep")
("make block wide" "blok breed maken")
("make check" "maak een check")
("make float wide" "strek zwevend object over volledige breedte")
("make floating" "laat zweven")
("make footnote wide" "voetnoot breed maken")
("make fraction" "maak een breuk")
("make grave" "maak een streepje naar links")
("make hat" "maak een hoedje")
("make label" "maak etiket")
("make link" "link maken")
("make negation" "maak een negatie")
("make non floating" "niet-zwevend maken")
("make opaque" "ondoorzichtig maken")
("make page reference" "maak pagina verwijzing")
("make reference" "maak verwijzing")
("make slides" "dia's maken")
("make square root" "maak een vierkantswortel")
("make tilde" "maak een slangetje")
("make title" "maak titel")
("make transparent" "transparant maken")
("make vector" "maak een vector")
("make wide" "breed maken")
("making donations" "ons een gift doen")
("manila paper" "manilla-papier")
("manila-paper" "manilla-papier")
("manual" "handleiding")
("manual path" "handmatig pad")
("map arguments" "zend argumenten")
("map to" "stuur naar")
("march" "maart")
("marginal note" "kanttekening")
("margins" "randen")
("margins as on paper" "randen net als op papier")
("margins from width" "marges volgens breedte")
("margins on paper" "marges op papier")
("margins on screen" "marges op scherm")
("marked" "gemarkeerd")
("marker" "marker")
("master" "meester")
("master file" "meester van bestand")
("material" "materiaal")
("math" "wiskunde")
("math Extra" "extra wiskundige tekens")
("math Letters" "wiskundige letters")
("math Symbols" "wiskundige symbolen")
("math font" "wiskunde lettertype")
("math font family" "familie wiskundig lettertype")
("math font series" "wiskundige lettersoort")
("math font shape" "wiskundige lettervorm")
("mathematical" "wiskundig")
("mathematical and customized input" "wiskundige en gepersonaliseerde invoer")
("mathematical font" "wiskundig lettertype")
("mathematical formulas" "wiskundige formules")
("mathematical input" "wiskundige invoer")
("mathematical output" "wiskundige uitvoer")
("mathematical typesetting" "wiskundige pagina-opmaak")
("mathematics" "wiskunde")
("matrices" "matrices")
("matrix" "matrix")
("matrix factorization" "matrixfactorisatie")
("maximal" "maximaal")
("maximal cell height" "maximale hoogte van de cel")
("maximal cell width" "maximale breedte van de cel")
("maximal clustering" "maximale clustering")
("maximal number of columns" "maximaal aantal kolommen")
("maximal number of rows" "maximaal aantal rijen")
("maximal table height" "maximale hoogte van de tabel")
("maximal table width" "maximale breedte van de tabel")
("maximum" "maximum")
("maximum mode" "maximum modus")
("may" "mei")
("meander" "meander")
("medieval" "middeleeuws")
("medium" "gewoon")
("medium skip" "gewone sprong")
("meminfo" "geheugen info")
("memory" "geheugen")
("memory usage" "geheugengebruik")
("menu" "menu")
("merge" "voeg samen")
("merge lines into paragraphs unless separated by blank lines" "regels samenvoegen in alinea's tenzij gescheiden door lege regels")
("messages" "berichten")
("messy" "warrig")
("meta data" "meta-gegevens")
("meta key" "meta toets")
("metadata" "meta-gegevens")
("metal" "metaal")
("middle" "midden")
("middle baseline" "middelste richtlijn")
("minimal" "minimaal")
("minimal cell height" "minimale hoogte van de cel")
("minimal cell width" "minimale breedte van de cel")
("minimal line separation" "minimale regelscheiding")
("minimal number of columns" "minimaal aantal kolommen")
("minimal number of rows" "minimaal aantal rijen")
("minimal table height" "minimale hoogte van de tabel")
("minimal table width" "minimale breedte van de tabel")
("minimum" "minimum")
("minimum mode" "minimum modus")
("minus" "strepen")
("mirror" "spiegel")
("miscellaneous" "divers")
("miscellaneous features" "diverse funktionaliteiten")
("miscellanous" "overige")
("mixed" "gemengd")
("mod" "mod")
("mode" "modus")
("mode dependent icons" "modusafhankelijke iconen")
("modifier" "veranderaar")
("modify bibliography" "bibliografie wijzigen")
("modify cell alignment" "plaatsing in cel")
("modify cell border" "verander rand cel")
("modify cell padding" "verander ruimte om cel")
("modify cell size" "verander grootte cel")
("modify remote live document" "live document op afstand wijzigen")
("modify table border" "rand tabel veranderen")
("modify table padding" "ruimte om tabel veranderen")
("module" "module")
("module browser" "modulebrowser")
("mongolian" "mongools")
("monospaced" "vaste-breedte")
("month" "maand")
("more information about GNU TeXmacs can be found in the Help" "meer informatie over GNU TeXmacs kunt U vinden in het Help")
("more information about GNU TeXmacs can be found in the Help->About menu" "meer informatie over GNU TeXmacs is te vinden in het menu Help-> Info")
("more information about GNU TeXmacs can be found in the help" "meer informatie
over GNU TeXmacs is te vinden in het Help menu")
("mosaic" "mozaïek")
("motion" "beweging")
("motion blur" "bewegingsvervaging")
("mouse over balloon" "muis over ballon")
("mouse over object" "muis boven object")
("move" "verplaats")
("move down" "ga naar beneden")
("move object" "verplaats object")
("move objects" "objecten verplaatsen")
("move over object on which to operate" "beweeg over het object dat moet worden
bewerkt")
("move to the right when finished" "ga naar rechts zodra klaar")
("move up" "ga naar boven")
("move::difference" "naar verschil")
("move::similar" "naar")
("multiline" "meerdere regels")
("multiline input" "meerdere regel invoer")
("multiple choice" "meerkeuze")
("multiple documents share window" "vensters gedeeld door meerdere documenten")
("multiple root" "meervoudige wortel")
("multiplication" "vermenigvuldiging")
("mutator tags" "constant veranderende tags")
("my bibliographic database" "mijn bibliografische databank")
("my documents" "mijn documenten")
("n-th" "n-de machts")
("n-th root" "n-de machts wortel")
("name" "naam")
("name of bibliography" "naam van bibliografie")
("name of glossary" "naam van de woordenlijst")
("name of index" "naam van de index")
("name of list of figures" "naam van de lijst met figuren")
("name of list of tables" "naam van de lijst met tabellen")
("name of table of contents" "naam van de inhoudsopgave")
("named" "benoemd")
("navigation options" "navigatie-opties")
("negation" "ontkenning")
("never" "nooit")
("new" "nieuw")
("new account" "nieuwe account")
("new bibliography dialogue" "nieuwe bibliografie dialoog")
("new buffer" "nieuwe buffer")
("new column" "nieuwe kolom")
("new context macro" "nieuwe contextmacro")
("new document" "nieuw document")
("new double page" "nieuwe dubbele pagina")
("new double page before" "nieuwe dubbele pagina hiervoor")
("new entry" "nieuwe item")
("new identity" "nieuwe identiteit")
("new item" "nieuw element")
("new line" "nieuwe regel")
("new locus" "nieuwe locus")
("new macro" "nieuwe macro")
("new number" "nieuw nummer")
("new page" "nieuwe pagina")
("new page before" "nieuwe pagina hiervoor")
("new paragraph" "nieuwe alinea")
("new passphrase" "nieuwe wachtzin")
("new remote directory" "nieuwe externe map")
("new remote file" "nieuw extern bestand")
("new roman" "nieuwe roman")
("new row" "nieuwe rij")
("new style fonts" "nieuwe stijl lettertypen")
("new style page breaking" "nieuwe stijl pagina-afbraak")
("new table" "nieuwe tabel")
("new table macro" "nieuwe tabelmacro")
("new version" "nieuwe versie")
("new window" "nieuw venster")
("newer version" "nieuwere versie")
("next" "volgende")
("next chunk" "volgende stuk")
("next difference" "volgend verschil")
("next error" "volgende fout")
("next field" "volgend veld")
("next line" "volgende regel")
("next occurrence" "volgende treffer")
("next screen" "volgend scherm")
("next similar" "volgende soortgelijke")
("no" "nee")
("no animation" "geen animatie")
("no changes need to be saved" "geen veranderingen hoeven te worden opgeslagen")
("no clustering" "geen clustering")
("no completions" "geen aanvullingen")
("no dictionary for" "geen woordenboek voor")
("no errors have been corrected" "er zijn geen fouten gecorrigeerd")
("no first indentation" "geen eerste inspringing")
("no grid" "geen rooster")
("no indentation" "geen inspringing")
("no line break" "breek regel niet af")
("no matches found" "ik heb geen treffers gevonden")
("no matches found for" "geen treffers gevonden voor")
("no more matches for" "niet meer treffers voor")
("no more redo information available" "niet meer informatie beschikbaar voor ``opnieuw''")
("no more undo information available" "niet meer informatie beschikbaar om terug te gaan")
("no multiple spaces" "geen meerdere spaties")
("no name" "zonder naam")
("no new public key in document" "geen nieuwe openbare sleutel in document")
("no page break" "geen pagina-einde")
("no page break after" "geen nieuwe pagina hierna")
("no page break before" "geen nieuwe pagina hiervoor")
("no page numbers" "geen paginanummers")
("no parent" "geen ouder")
("no selection" "geen selectie")
("no spelling errors" "geen spelfouten")
("no spelling errors found in text" "geen spelfouten ontdekt in tekst")
("no spurious spaces" "geen onnodige spaties")
("no style" "geen documentstijl")
("none" "geen")
("normal" "normaal")
("normal loci" "normale loci")
("normal size" "normale grootte")
("norwegian" "noors")
("not" "niet")
("not allowed to remove home directory" "hoofdmap mag niet worden verwijderd")
("not connected to server" "niet verbonden met server")
("not equal" "ongelijk")
("not found" "niet gevonden")
("not yet implemented" "nog niet geïmplementeerd")
("notation" "notatie")
("notations" "notaties")
("note" "aantekening")
("notebook" "notitieboek")
("notes" "notities")
("november" "november")
("number" "getal")
("number equation" "nummer de vergelijking")
("number of columns" "aantal kolommen")
("number of polar steps" "aantal polaire stappen")
("number of subunit steps" "aantal stappen voor subeenheden")
("numbered" "genummerd")
("numbered equation" "genummerde vergelijking")
("numbered equations" "genummerde vergelijkingen")
("numbering" "nummering")
("numerator" "teller")
("numeric" "numeriek")
("numeric analysis" "numerieke analyse")
("numeric comma table" "tabel met decimale komma's")
("numeric dot table" "tabel met decimale punten")
("numeric spreadsheet" "numerieke spreadsheet")
("objectives" "doel")
("oblique" "schuin")
("occurrences" "treffers vervangen")
("october" "oktober")
("odd page" "oneven pagina")
("odd page footer" "oneven pagina voet")
("odd page header" "oneven pagina kop")
("odd page left margin" "oneven pagina linkerrand")
("odd page margin" "oneven pagina rand")
("odd page right margin" "oneven pagina rechterrand")
("odd page shift" "oneven pagina verschuiving")
("odd page text" "oneven pagina tekst")
("odd pages" "oneven pagina's")
("of fingerprint" "met vingerafdruk")
("off" "uit")
("ok" "ok")
("old english" "oud engels")
("old slavonic" "oud slavisch")
("old style" "oude interface")
("old version" "oude versie")
("older version" "oudere versie")
("on" "aan")
("on cells" "per cel")
("on columns" "per kolom")
("on entire table" "per hele tabel")
("on rows" "per rij")
("on the footer" "op de statusbalk")
("on your system and set it up from the \"Security\" tab" "op uw systeem en stel dit in vanaf het tabblad \"Beveiliging \"")
("once" "eenmalig")
("one column" "één kolom")
("one error has been corrected" "één fout is gecorrigeerd")
("one lower case letter, one non alpha-numeric symbol" "één kleine letter, één niet-alfanumeriek symbool")
("one numeric character, one upper case letter" "één numeriek teken, één hoofdletter")
("one spelling error has been corrected" "één spelfout is gekorrigeerd")
("online documentation" "on-line documentatie")
("online help" "hulp van het web")
("only convert changes when re-importing" "wijzigingen alleen converteren bij opnieuw importeren")
("only convert changes with respect to imported version" "alleen wijzigingen converteren ten opzichte van de geïmporteerde versie")
("only convert changes with respect to tracked version" "converteer alleen wijzigingen ten opzichte van de bijgehouden versie")
("only implemented for complete subtrees" "alleen geïmplementeerd voor volledige substructuren")
("only inline tags" "alleen regel-tags")
("only keep folded" "alleen opgevouwen tags behouden")
("only keep unfolded" "alleen opengevouwen tags behouden")
("only show paragraphs with hits" "toon alleen alinea's met treffers")
("only show semantic focus" "toon alleen de semantische focus")
("opacity" "dekking")
("open" "open")
("open a new buffer" "open een nieuwe buffer")
("open bibliography" "bibliografie openen")
("open identities" "identiteiten openen")
("open in new window" "in nieuw venster openen")
("open key manager" "sleutelbeheerder openen")
("open licence agreement" "licentieovereenkomst openen")
("open mailbox" "mailbox openen")
("open module browser" "module browser openen")
("open new window" "nieuw venster openen")
("open on errors" "open in geval van fouten")
("open on warnings" "open in geval van waarschuwingen")
("open symbol browser" "symboolbrowser openen")
("open tool in separate window" "open gereedschap in apart venster")
("opening" "aanvang")
("operation mode" "operatiemodus")
("operation on named selection" "operatie op aan te geven selectie")
("operation on primary selection" "operatie op hoofdselectie")
("operation on secondary selection" "operatie op tweede selectie")
("operation on ternary selection" "operatie op derde selectie")
("optical" "optisch")
("option" "optie")
("options" "opties")
("or" "of")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "of geef het volledige pad naar het commando \"gpg\" of \"gpg2\"")
("orange" "oranje")
("order" "volgorde")
("ordinary symbol" "gewoon symbool")
("orientation" "oriëntatie")
("origin" "oorsprong")
("original welcome message" "oorspronkelijk welkomsbericht")
("ornamented" "versierd")
("other" "anders")
("other login" "andere login")
("other package" "ander pakket")
("other pages" "ander paginas")
("other projects" "andere projecten")
("other style" "andere stijl")
("outer" "buitenkant")
("outer bottom" "bodem van buiten")
("outer left" "links buiten")
("outer right" "rechts buiten")
("outer top" "top van buiten")
("outline" "contour")
("outlined" "contouren")
("outlined emboss" "schets reliëf")
("outlined engrave" "schets gegraveerd")
("outlined roman" "omlijnd")
("output" "uitvoer")
("output options" "uitvoeropties")
("outwards" "naar buiten")
("oval" "ovaal")
("oval blur" "ovale vervaging")
("over" "gedeeld door")
("overbrace" "accolade over")
("overlap" "overlapping")
("overlay" "overlay")
("overlay mode" "overlaymodus")
("overlays" "overlays")
("overline" "overstreept")
("overlined" "bovenstreept")
("overview of the scheme extension language" "overzicht van de Scheme extensie-taal")
("padded" "opvulling")
("padding" "extra ruimte")
("padding above" "opvulling hierboven")
("padding below" "opvulling hieronder")
("page" "pagina")
("page background" "pagina achtergrond")
("page bottom margin" "pagina beneden rand")
("page break" "breek pagina af")
("page break after" "pagina-einde hierna")
("page break before" "breek pagina hiervoor af")
("page breaking algorithm" "algoritme voor pagina-afbraak")
("page format" "pagina-indeling")
("page height" "pagina lengte")
("page insertion" "pagina invoeging")
("page layout" "pagina indeling")
("page number" "paginanummer")
("page number rendering" "weergave van paginanummer")
("page number text" "paginanummer tekst")
("page numbering" "paginanummering")
("page reference" "pagina verwijzing")
("page rendering" "paginaweergave")
("page right margin" "pagina rechter rand")
("page setup" "paginainstelling")
("page top margin" "pagina boven rand")
("page type" "pagina type")
("page width" "pagina breedte")
("pagedown" "pagedown")
("pages" "pagina's")
("pageup" "pageup")
("pale blue" "lichtblauw")
("palette" "palet")
("panorama" "panorama")
("paper" "papier")
("paper size" "papierformaat")
("paper type" "papierformaat")
("papyrus" "papyrus")
("paragraph" "alinea")
("paragraph format" "alinea-indeling")
("paragraph mode" "alineatype")
("paragraph width" "alineabreedte")
("paragraph::section" "paragraaf")
("paragraphs" "alinea's")
("parametric curve" "geparametriseerde kromme")
("parametric surface" "geparametriseerd oppervlak")
("parchment" "perkament")
("parenthesis" "haakjes")
("parenthesized" "met haakjes")
("parser" "parser")
("part" "deel")
("particle" "predicaat")
("passphrase decryption" "decodering met wachtzin")
("passphrase encryption" "codering met wachtzin")
("passphrase wallet facilities are not currently available" "faciliteiten voor
portemonnee met wachtzinnen zijn momenteel niet beschikbaar")
("passphrases are expected to have at least: 8 characters" "wachtzinnen moeten ten minste 8 tekens bevatten")
("passphrases mismatch" "paszinnen komen niet overeen")
("password" "wachtwoord")
("past changes" "gemaakte veranderingen")
("paste" "plak")
("paste from" "plak uit")
("paste text" "plak tekst")
("pastel" "pastel")
("path" "pad")
("pattern" "patroon")
("pattern selector" "patroon kiezen")
("pause" "pauze")
("pdf version number" "pdf versienummer")
("pen" "pen")
("pen angle" "invalshoek")
("pen height" "penhoogte")
("pen width" "penbreedte")
("perform operations on cells" "doe operaties celsgewijze")
("perform operations on columns" "doe operaties kolomsgewijze")
("perform operations on entire table" "doe operaties op hele tabel")
("perform operations on rows" "doe operaties op rijen")
("permanent" "permanent")
("permanent footer" "permanente voettekst")
("permanent header" "permanente koptekst")
("permanently add to dictionary" "permanent toevoegen aan woordenboek")
("permanently insert into dictionary" "permanent toevoegen aan woordenboek")
("permissions" "machtigingen")
("person" "persoon")
("personal dictionary has been modified" "Uw persoonlijke woordenboek is veranderd")
("phantasy" "fantasie")
("phantom" "spook")
("phantoms" "spoken")
("philosophy" "filosofie")
("phoenician" "phoeniciaans")
("phonetic" "fonetisch")
("physics and astronomy class" "natuurkunde- en astronomieklasse")
("picture" "plaatje")
("pine" "grenen hout")
("pink" "rose")
("plain" "gewoon")
("plain block" "standaard blok")
("plain boxes" "gewone vakjes")
("plain circles" "gewone cirkels")
("plain tabular" "standaard tabel")
("planned changes" "geplande veranderingen")
("plans for the future" "plannen voor de toekomst")
("play" "afspelen")
("play all animations" "alle animaties afspelen")
("play animation" "animatie afspelen")
("please" "graag")
("please install GnuPG software from https://www.gnupg.org" "installeer GnuPG-software van https://www.gnupg.org")
("please wait" "een ogenblik a.u.b.")
("plot" "grafiek")
("plots editor" "plots editor")
("plug-ins" "plug-ins")
("plugin" "plug-in")
("plugins" "plug-ins")
("plural" "meervoudig")
("plus" "plus")
("point" "punt")
("point border" "puntrand")
("point size" "puntgrootte")
("point style" "puntstijl")
("polar" "polair")
("polish" "pools")
("polygon" "polygoon")
("polynomial arithmetic" "polynomen")
("pop server settings" "pop-serverinstellingen")
("porting TeXmacs to other platforms" "TeXmacs overzetten naar andere systemen")
("portion" "portie")
("portrait" "portret")
("portuguese" "portugees")
("position" "positie")
("position float" "positioneer drijver")
("position floating object" "positioneer zwevend objekt")
("position of marginal note" "positie van kanttekening")
("position the table" "plaats de tabel")
("poster" "poster")
("poster formats" "posterformaten")
("poster theme" "poster thema")
("postfix" "postfix")
("postscript" "postscript")
("postscript image" "postscript plaatje")
("pre-alpha release" "pré-alpha versie")
("preamble" "preambule")
("preamble mode" "preambulemodus")
("preferences" "voorkeuren")
("preferences for editing mathematical formulas" "voorkeuren voor het bewerken van wiskundige formules")
("preferences for tag" "voorkeuren voor tag")
("prefix" "voorvoegsel")
("prefix by section number" "sectienummer als voorvoegsel")
("presentation" "presentatie")
("presentation mode" "presentatiemodus")
("presentation tag" "uiterlijk")
("presentation tool" "gereedschap voor presentaties")
("preserve" "behouden")
("preserve tags" "tags behouden")
("preserving syntactic correctness while editing mathematical formulas" "syntactische correctheid behouden tijdens het bewerken van wiskundige formules")
("pretty" "mooi")
("pretty scheme tree output" "mooie uitvoer van Scheme bomen")
("pretty tree output" "bomen mooi presenteren")
("preview" "vooraf zien")
("preview before printing" "zien voor het printen")
("preview command" "kommando om vooraf te zien")
("preview with ghostview" "vooraf zien met ghostview")
("previous" "vorige")
("previous difference" "vorig verschil")
("previous error" "vorige fout")
("previous field" "vorig veld")
("previous occurrence" "vorige treffet")
("previous screen" "vorig scherm")
("previous similar" "vorige soortgelijke tag")
("primary" "eerste")
("prime" "priem")
("primitive or macro" "ingebouwde tag of macro")
("print" "druk af")
("print all" "druk alles af")
("print all to file" "druk alles af naar bestand")
("print buffer" "buffer afdrukken")
("print buffer to file" "buffer naar bestand afdrukken")
("print document" "document afdrukken")
("print page selection" "druk gedeelte af")
("print page selection to file" "druk gedeelte af naar bestand")
("print to file" "afdrukken naar bestand")
("print to postscript file" "naar postscript bestand")
("printer" "printer")
("printer dpi" "printers resolutie in punten per duim")
("printer setup" "printerinstellingen")
("printing command" "kommando om af te drukken")
("problem" "probleem")
("problems" "problemen")
("proceed" "doorgaan")
("produce Pdf using native export filter" "Pdf produceren met ingebouwde exportfilter")
("produce Postscript using native export filter" "Postscript produceren met ingebouwde exportfilter")
("professional" "professioneel")
("prog" "programma")
("prog font" "programmeer lettertype")
("prog font family" "familie programmeer lettertype")
("prog font series" "programma lettersoort")
("prog font shape" "programma lettervorm")
("program" "programma")
("program bracket matching" "overeenkomst van haken in programma's")
("program bracket selections" "selectie van haken in programma's")
("program commands" "programma-opdrachten")
("program font" "lettertype voor programmas")
("program interface for buffer management" "programma-interface voor bufferbeheer")
("program mode" "programmamodus")
("programming" "programma")
("programming routines for editing documents" "routines programmeren voor het bewerken van documenten")
("progressive" "geleidelijk")
("project" "projekt")
("projector" "projector")
("projects" "projecten")
("prologue" "voorwoord")
("prominent" "prominent")
("prompt on scripts" "vraag bij elke script")
("prompts and default input" "prompts en invoer-suggesties")
("proof" "bewijs")
("proofs" "bewijzen")
("properties" "eigenschappen")
("proportional" "proportioneel")
("proportional typewriter" "proportionele schrijfmachine")
("property" "eigenschap")
("proposition" "propositie")
("propositions" "proposities")
("provoke C++ error" "C++ fout veroorzaken")
("provoke menu error" "menu fout veroorzaken")
("provoke scheme error" "Scheme fout veroorzaken")
("pseudo code" "pseudocode")
("public key encryption" "codering met openbare sleutel")
("public keys" "openbare sleutels")
("pulse" "puls")
("qt GUI only, sorry. Use \"Export selection\"" "Alleen qt GUI, sorry. Gebruik \"Selectie exporteren\"")
("qt-widgets" "qt-widgets")
("quadratic forms" "kwadratische vormen")
("quantifier" "quantor")
("quasi" "quasi")
("query replace" "tekst op gecontroleerde wijze vervangen")
("question" "vraag")
("questions" "vragen")
("questions only" "alleen vragen")
("questions with answers" "vragen met antwoorden")
("quick evaluation of formulas" "snelle evaluatie van formules")
("quit" "verlaat")
("quotation" "citaat")
("quote" "citeren")
("radius" "straal")
("radius x" "straal x")
("radius y" "straal y")
("range" "deel")
("rank" "rang")
("raw" "rauw")
("real" "reële getallen")
("really close it" "echt sluiten")
("really delete user identity" "gebruikersidentiteit echt verwijderen")
("really huge" "echt enorm")
("really quit" "wilt u echt ophouden")
("really tiny" "werkelijk miniem")
("rebuild translations file" "vertaalbestand opnieuw opbouwen")
("recent" "recentelijk")
("recent documents" "recentelijke documenten")
("recipients" "ontvangers")
("recognize" "herkennen")
("recolor" "opnieuw kleuren")
("recover autosave file" "herstel veiligheidsbestand")
("rectangle" "rechthoek")
("rectangular" "rechthoekig")
("red" "rood")
("reddish" "roodachtig")
("redo" "opnieuw")
("redo undone changes" "maak ongedane veranderingen opnieuw geldig")
("reduce" "verkleinen")
("reduce bottom margin by" "verklein onder rand met")
("reduce by" "verkleinen met")
("reduce left margin by" "verklein linker rand met")
("reduce margins" "randen verkleinen")
("reduce right margin by" "verklein rechter rand met")
("reduce top margin by" "verklein boven rand met")
("reduce trigonometric functions" "trigonometrische funkties inkorten")
("reduced margins" "verkleinde marges")
("reduction even page margin" "verkleining even pagina rand")
("reduction odd page margin" "verkleining oneven pagina rand")
("reduction page bottom margin" "verkleining pagina beneden rand")
("reduction page right margin" "verkleining pagina rechter rand")
("reduction page top margin" "verkleining pagina boven rand")
("reference" "verwijzing")
("reference guide" "referentie gids")
("reference guide for the TeXmacs primitives" "gids voor de TeXmacs primitieven")
("reference guide for the standard TeXmacs styles" "gids voor de standaard TeXmacs stijlen")
("reference to note" "verwijzing naar aantekening")
("references" "verwijzingen")
("regenerate" "regenereren")
("register" "registreren")
("register file" "bestand registreren")
("regular" "normaal")
("relate" "verbinden")
("relation" "relatie")
("release" "versie")
("release left button: finish editing" "linkerknop loslaten: bewerking voltooien")
("reload" "herlaad")
("remark" "opmerking")
("remarks" "opmerkingen")
("remote" "op afstand")
("remote connections" "externe verbindingen")
("remote control" "afstandsbediening")
("remote controllers with keyboard simulation" "afstandsbedieningen met toetsenbordsimulatie")
("remote directory" "externe map")
("remote login" "inloggen op externe server")
("remote plug-ins" "externe plug-ins")
("remote servers" "externe servers")
("remote tool" "gereedschappen voor werk op afstand")
("remove" "verwijder")
("remove all output fields" "verwijder alle uitvoervelden")
("remove animation" "animatie verwijderen")
("remove argument after" "argument hierna verwijderen")
("remove argument before" "argument hiervoor verwijderen")
("remove banner" "startbericht verwijderen")
("remove database entry" "database item verwijderen")
("remove downwards" "naar beneden verwijderen")
("remove entries" "items verwijderen")
("remove entry" "item verwijderen")
("remove field above" "veld hierboven verwijderen")
("remove field below" "veld hieronder verwijderen")
("remove fields" "velden verwijderen")
("remove folded" "opgevouwen objecten verwijderen")
("remove from previous frames" "verwijderen uit vorige frames")
("remove from subsequent frames" "verwijderen uit volgende frames")
("remove input field" "verwijder invoerveld")
("remove input field above" "verwijder invoerveld hierboven")
("remove last field" "laatste veld verwijderen")
("remove leftwards" "naar links verwijderen")
("remove link" "link verwijderen")
("remove next field" "volgend veld verwijderen")
("remove number" "nummer verwijderen")
("remove overlay after" "overlay hierna verwijderen")
("remove overlay before" "overlay hiervoor verwijderen")
("remove package" "schrap pakket")
("remove previous field" "vorig veld verwijderen")
("remove remote ssh connection" "ssh-verbinding verwijderen")
("remove rightwards" "naar rechts verwijderen")
("remove selected database entries" "geselecteerde database items verwijder")
("remove selected entries" "geselecteerde items verwijderen")
("remove slide after" "slide hierna verwijderen")
("remove slide before" "slide hiervoor verwijderen")
("remove superfluous invisible operators" "overbodige onzichtbare operatoren verwijderen")
("remove tag" "tag verwijderen")
("remove this branch" "deze tak verwijderen")
("remove this frame" "dit frame verwijderen")
("remove this switch" "schakelaar verwijderen")
("remove unfolded" "opengevouwen objecten verwijderen")
("remove upwards" "naar boven verwijderen")
("removed entries from database" "items uit database verwijderd")
("removed entry from database" "item uit database verwijderd")
("rename" "nieuwe naam")
("rename section" "sectie nieuwe naam geven")
("rendering" "weergave")
("rendering options for tag" "weergaveopties voor tag")
("renumber this page" "hernummer deze pagina")
("repeat" "herhaal")
("repeat object" "herhaal object")
("replace" "vervang")
("replace TeXmacs styles with no LaTeX equivalents" "vervang TeXmacs-stijlen zonder LaTeX-equivalenten")
("replace all further occurrences" "alle verdere treffers vervangen")
("replace by" "vervang door")
("replace one occurrence" "één treffer vervangen")
("replace toolbar" "werkbalk om tekst te vervangen")
("replace unrecognized styles" "vervang onbekende stijlen")
("replaced" "ik heb")
("replaced one occurrence" "ik heb één treffer vervangen")
("research papers" "onderzoeksartikelen")
("reset" "herzet")
("reset error counters" "herstart foutentellers")
("resize" "grootte wijzigen")
("resize object" "verander grootte object")
("resize objects" "grootte van objecten wijzigen")
("resized" "uitgerekt")
("restart TeXmacs in order to let changes take effect" "herstart TeXmacs om wijzigingen van kracht te laten worden")
("restart in order to let the new look and feel take effect" "herstart om het nieuwe uiterlijk van kracht te laten worden")
("retain" "behouden")
("retime" "tijdverloop")
("retina settings" "retina-instellingen")
("retrieve email" "e-mail ophalen")
("retrieve remote live document" "extern document ophalen")
("retrieved contents" "opgehaalde inhoud")
("retro" "retro")
("return" "return")
("reverse" "omgekeerd")
("reverse ordering" "omgekeerde volgorde")
("revert" "herlaad")
("revert buffer" "herlaad")
("rewriting" "herschrijven")
("ridged paper" "geribbeld papier")
("ridged-paper" "geribbeld papier")
("right" "rechts")
("right aligned" "rechts uitgelijnd")
("right arrow" "pijl naar rechts")
("right baseline" "rechter richtlijn")
("right border" "rechter rand")
("right cell border" "rechter celrand")
("right cell padding" "ruimte rechterkant cel")
("right down" "rechts beneden")
("right margin" "rechter rand")
("right on even pages" "rechts op even pagina's")
("right padding" "ruimte rechts")
("right subscript" "rechter subscript")
("right superscript" "rechter exponent")
("right surrounding" "rechter omgeving")
("right table border" "rechter tabelrand")
("right table padding" "ruimte rechterkant tabel")
("right up" "rechts boven")
("rightwards" "naar rechts")
("rigid" "stijf")
("rigid box" "stijve rechthoek")
("rigid horizontal" "stijf horizontaal")
("rigid space" "stijve spatie")
("ring binder notebook style" "ringband notitieboekstijl")
("romanian" "roemeens")
("root" "wortel")
("rotate" "draaien")
("rotate backward" "terug draaien")
("rotate forward" "vooruit draaien")
("rotate objects" "objecten draaien")
("rough" "ruw")
("rough paper" "ruw papier")
("rough-paper" "ruw papier")
("round" "rond")
("round overbrace" "ronde haak boven")
("round underbrace" "ronde haak onder")
("rounded" "afgerond")
("row" "rij")
("row above" "rij naar boven")
("row below" "rij naar beneden")
("row contains glued items" "rij bevat aan elkaar gelijmde delen")
("rows" "rijen")
("run" "uitvoeren")
("run current file" "huidig bestand uitvoeren")
("runic" "runen")
("running author" "lopende auteur")
("running title" "lopende titel")
("russian" "russisch")
("russian and Ukrainian users" "Russische en Ukraeense gebruikers")
("same names" "dezelfde namen")
("same screen margins as on paper" "dezelfde marges op het scherm en op papier")
("sample" "proef")
("sample text" "voorbeeldtekst")
("sans serif" "schreefloos")
("save" "sla op")
("save TeXmacs file" "berg TeXmacs bestand op")
("save TeXmacs style file" "berg TeXmacs stijl bestand op")
("save all embedded images" "alle ingesloten afbeeldingen opslaan")
("save as" "sla op als")
("save as LaTeX" "sla op als LaTeX")
("save as TeX" "sla op als TeX")
("save auxiliary data" "hulpgegevens opslaan")
("save buffer" "berg buffer op")
("save buffer as" "berg buffer op als")
("save entries" "items opslaan")
("save entry" "item opslaan")
("save file" "berg bestand op")
("save html file" "berg html bestand op")
("save image" "berg plaatje op")
("save image as" "plaatje opslaan als")
("save latex file" "berg latex bestand op")
("save position" "positie opslaan")
("save remote file" "extern bestand opslaan")
("save tex file" "berg tex bestand op")
("save this buffer" "berg deze buffer op")
("save verbatim file" "berg verbatim bestand op")
("saved" "opgeborgen")
("saved modifications in database" "wijzigingen opgeslagen in database")
("scale of the graphical user interface" "schaal van de gebruikersinterface")
("scale graphical interface" "schaal van de gebruikersinterface")
("scheme command" "scheme kommando")
("scheme developers guide" "gids voor Scheme ontwikkelaars")
("scheme extensions" "uitbreidingen in Scheme")
("scheme interface for the graphical mode" "Scheme interface voor de grafische modus")
("screen" "scherm")
("screen layout" "scherm indeling")
("screen margins" "randen op het scherm")
("screen rendering" "weergave op het scherm")
("screens" "schermen")
("screenshot" "screenshot")
("script" "subscripts en exponenten")
("script above" "onderschrift")
("script below" "bovenschrift")
("script script size" "subsubscript grootte")
("script size" "subscript grootte")
("scripting language" "taal voor scripts")
("scripts" "scripts")
("scripts not accepted" "scripts worden niet geaccepteerd")
("search" "zoek")
("search and replace" "zoeken en vervangen")
("search in database" "zoeken in database")
("search results for" "resultaten voor het zoeken naar")
("search toolbar" "werkbalk om tekst te zoeken")
("search words in my documents" "zoek woorden in mijn documenten")
("search words in the documentation" "zoek woorden in de documentatie")
("search words in the source code" "zoek woordern in de programmacode")
("searching" "zoek")
("second" "tweede")
("secondary" "tweede")
("secret keys" "geheime sleutels")
("section" "sectie")
("sections" "secties")
("security" "veiligheid")
("see" "zie")
("see documentation" "zie documentatie")
("select GnuPG recipients" "selecteer GnuPG-ontvangers")
("select a document style" "selekteer een documentstijl")
("select a foreground color" "selekteer een voorgrondkleur")
("select a language" "selekteer een taal")
("select background picture" "achtergrond selecteren")
("select color" "kleur selecteren")
("select document style" "documentstijl selecteren")
("select pen" "pen selecteren")
("select the action to be undertaken for each conflict" "selecteer de actie die moet worden ondernomen voor elk conflict")
("select view mode" "selecteer weergavemodus")
("selected region" "geselecteerde streek")
("selection" "selectie")
("selections" "selecties")
("semantic correctness" "semantische correctheid")
("semantic editing" "semantische bewerking")
("semantic selections" "semantische selecties")
("semantics" "semantiek")
("seminar" "voordracht")
("sending commands to TeXmacs" "kommandos naar TeXmacs zenden")
("senior" "senior")
("separation between lines" "aftand tussen regels")
("separation between paragraphs" "afstand tussen paragrafen")
("separator" "afscheider")
("september" "september")
("serb" "servisch")
("series" "soort")
("series|right" "rechtop")
("serif" "schreven")
("server" "server")
("server licence agreement" "licentieovereenkomst voor de server")
("session" "sessie")
("session commands" "sessiecommando's")
("session name" "naam van de sessie")
("session type" "type sessie")
("sessions" "sessies")
("set" "zet")
("set background color of cell" "achtergrondskleur cel")
("set cell mode" "verander celmodus")
("set default" "standaardinstelling")
("set difference" "relatief complement")
("set extension center" "centrum voor uitbreidingen")
("set height" "verander hoogte")
("set height of cell" "verander hoogte cel")
("set intersection" "doorsnijding")
("set margins" "verander randen")
("set n" "voer n in")
("set number of columns" "aantal kolommen instellen")
("set number of rows" "aantal rijen instellen")
("set or get environment variables" "verander of lees omgevingsvariabelen")
("set paragraph margins" "verander alinea randen")
("set paragraph mode" "verander alineatype")
("set printer dpi" "stel printers resolutie in")
("set printing command" "kommando om af te drukken")
("set properties" "eigenschappen instellen")
("set span" "verander rijkwijdte")
("set special cell properties" "speciale celeigenschappen")
("set special table properties" "speciale tabeleigenschappen")
("set text width" "verander tekst breedte")
("set union" "vereniging")
("set user information" "gebruikersinformatie instellen")
("set width" "verander breedte")
("set width of cell" "verander breedte cel")
("settings" "instelling")
("setup printer" "stel printer in")
("seventh" "zevende")
("several equations" "meerdere vergelijkingen")
("shadow" "schaduw")
("shadowed" "met schaduw")
("shadowed raise" "omhoog met schaduw")
("shape" "vorm")
("sharpness" "scherpte")
("shift" "verschuif")
("shift-down" "shift-onder")
("shift-right" "shift-rechts")
("short" "kort")
("shortcut" "afkorting")
("show" "zie")
("show all parts" "toon alle delen")
("show current focus" "toon huidige focus")
("show full context" "volledige context weergeven")
("show grid" "toon het rooster")
("show header and footer" "kop en voet laten zien")
("show hidden" "zie verborgen gedeelte")
("show key presses" "toetsaanslagen weergeven")
("show main document" "hoofddocument weergeven")
("show memory usage" "geheugengebruik weergeven")
("show on screen" "zien op het scherm")
("show one part" "toon één deel")
("show panorama" "panorama weergave")
("show preamble" "toon preambule")
("show several parts" "toon meerdere delen")
("show subunits" "subeenheden weergeven")
("show table cells" "tabelcellen weergeven")
("show timings" "laat timings zien")
("shrinking factor" "krimpfaktor")
("side tools" "gereedschap aan de zijkant")
("signature" "handtekening")
("simple" "eenvoudig")
("simple form" "eenvoudig formulier")
("simple widget" "eenvoudige widget")
("simplification" "versimpelen")
("simplified evaluation of formulas" "versimpeld evalueren van formules")
("simplified menus" "versimpelde menus")
("simplify" "versimpel")
("sine" "sinus")
("sine and cosine" "sinus en cosinus")
("sixth" "zesde")
("size" "grootte")
("size limits" "limieten aan grootte")
("size tag" "grootte")
("skew" "scheef")
("skin" "huid")
("skip all" "alles overslaan")
("slant" "schuin")
("slanted" "scheef")
("slashed fraction" "schuine streep breuk")
("slide" "dia")
("slides" "slides")
("sloppy" "slobberig")
("slovak" "slowaaks")
("slovene" "sloveens")
("slow" "langzaam")
("slow decrease" "langzame afname")
("slow increase" "langzame toename")
("small" "klein")
("small Capitals" "kleine hoofdletters")
("small capitals" "kleine hoofdletters")
("small caps" "kleine hoofdletters")
("small environment box" "kleine omgevingsrechthoek")
("small figure" "klein figuur")
("small focus" "kleine focus")
("small inline" "kleine inline")
("small inline fraction" "kleine inline breuk")
("small skip" "kleine sprong")
("small table" "kleine tabel")
("smash" "verpletten")
("smooth" "glad")
("smooth end" "glad einde")
("smooth extremities" "gladde uiteinden")
("smooth start" "gladde start")
("snap" "magnetisch")
("snap distance" "afstand voor magnetische werking")
("snap to curves" "magnetische krommen")
("snap to grid" "magnetisch roosterpunten")
("snap to grid curve" "magnetische roosterlijnen")
("snap to intersections of curves" "magnetische snijpunten van krommen")
("snap to pages" "op pagina's afstemmen")
("snap to text borders" "magnetische tekstranden")
("snap to text corners" "magnetische teksthoeken")
("solution" "oplossing")
("solution to exercise" "oplossing voor de oefening")
("solution to problem" "oplossing voor het probleem")
("solutions" "oplossingen")
("solve" "oplossen")
("solve in" "oplossen in")
("solving equations" "vergelijkingen oplossen")
("sound" "geluid")
("source" "bron")
("source code" "programmacode")
("source directory" "bronmap")
("source macros tool" "gereedschap voor broncode")
("source tags" "weergave bomen")
("south" "zuiden")
("south east" "zuidoost")
("space" "spatie")
("space bar in math mode" "spatiebalk in wiskundemodus")
("space bar in text mode" "spatiebalk in tekstmodus")
("space between lines" "afstand tussen regels")
("space between paragraphs" "afstand tussen paragrafen")
("space stretchability" "rekbaarheid van lege ruimtes")
("spacing" "afstanden")
("span" "spanning")
("span over all columns" "overspanning over alle kolommen")
("spanish" "spaans")
("special" "speciaal")
("special cell properties" "speciale celeigenschappen")
("special cell properties and actions" "speciale celeigenschappen en acties")
("special functions" "speciale funkties")
("special properties" "speciale eigenschappen")
("special table properties" "speciale tabeleigenschappen")
("specific" "specifiek")
("specific baseline" "specifieke richtlijn")
("specified" "gespecificeerd")
("specify color alternation" "kleurafwisseling specificeren")
("specify how to traverse the manual" "specificeren hoe de handleiding moet worden doorlopen")
("specify semantics of a symbol or formula" "semantiek van een symbool of formule specificeren")
("specify the size of the table" "grootte van de tabel bepalen")
("specify user identity" "gebruikersidentiteit specificeren")
("spell" "spel")
("spell check" "spellingcontrole")
("spell checking complete" "klaar met het doornemen van spelfouten")
("spelling error" "spelfout")
("spelling errors have been corrected" "spelfouten zijn gekorrigeerd")
("spline" "spline")
("split" "splijt")
("split program" "programma splitsen")
("split session" "splijt sessie")
("square" "vierkant")
("square overbrace" "vierkante haak boven")
("square root" "vierkantswortel")
("square underbrace" "vierkante haak onder")
("stack" "stapel")
("standard" "standaard")
("standard Output" "standaarduitvoer")
("standard TeXmacs styles" "standaard TeXmacs stijlen")
("standard environment variables" "standaard omgevingsvariabelen")
("standard formats" "standaard formaten")
("standard fraction" "standaard breuk")
("star" "ster")
("start" "start")
("start a new chapter" "begin met een nieuw hoofdstuk")
("start a new section" "begin met een nieuwe sectie")
("start an interactive session" "start een interaktieve sessie")
("start remote session" "sessie op afstand starten")
("start server" "start server")
("statement" "verklaring")
("statistics" "statistieken")
("status" "status")
("status bar" "status balk")
("stop server" "server stoppen")
("storage" "opslag")
("store tracking information in LaTeX files" "volginformatie opslaan in LaTeX-bestanden")
("strength" "sterkte")
("stretch" "strek uit")
("stretch factor" "rekfactor")
("stretchable" "uitrekbaar")
("stretchable horizontal" "horizontaal uitrekbaar")
("stretchable vertical" "vertikaal uitrekbaar")
("stretched" "uitgerekt")
("strict Ascii" "strikte Ascii")
("strike through" "doorhalen")
("stroke" "streep")
("strokes" "strepen")
("strong" "belangrijk")
("structural" "struktureel")
("structured insert above" "gestructureerd invoegen naar boven")
("structured insert at the left" "gestructureerd invoegen naar links")
("structured insert at the right" "gestructureerd invoegen naar rechts")
("structured insert below" "gestructureerd invoegen naar beneden")
("structured remove downwards" "gestructureerd naar beneden verwijderen")
("structured remove leftwards" "gestructureerd naar links verwijderen")
("structured remove rightwards" "gestructureerd naar rechts verwijderen")
("structured remove upwards" "gestructureerd naar boven verwijderen")
("structured variant" "gestructureerde variant")
("style" "stijl")
("style options" "stijlopties")
("style parameters" "stijlparameters")
("styles" "stijlen")
("stylesheet language" "taal voor stijlbestanden")
("sub" "onder")
("subject" "onderwerp")
("submenu" "submenu")
("subparagraph" "onderparagraaf")
("subparagraphs" "onderparagrafen")
("subscript" "subscript")
("subscript below" "subscript hieronder")
("subsection" "deelsectie")
("subsections" "deelsecties")
("subsub" "onder onder")
("subsubmenu" "subsubmenu")
("subsubsection" "subsubsectie")
("subsubsections" "subsubsecties")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtabel")
("subtitle" "ondertitel")
("subtraction" "aftrekking")
("summarized" "samengevat")
("summary" "samenvatting")
("summary of the principal TeXmacs tags" "de voornaamste TeXmacs tags")
("superpose" "opeenstapelen")
("superposed" "opeengestapeld")
("superscript" "exponent")
("superscript above" "superscript hierboven")
("supported plug-ins" "ondersteunde plug-ins")
("surface" "oppervlak")
("surveys" "overzichtsartikelen")
("swedish" "zweeds")
("swiss" "zwitsers")
("switch" "schakelaar")
("switch to buffer" "overschakelen naar buffer")
("switch to first" "schakel naar eerste")
("switch to formula style" "gebruik formule stijl")
("switch to last" "schakel naar laatste")
("switch to next" "schakel naar volgende")
("switch to previous" "schakel naar vorige")
("switching and folding" "schakelen en vouwen")
("symbol" "symbool")
("symbol browser" "symboolbrowser")
("symbol properties not found" "symbooleigenschappen niet gevonden")
("symbols" "symbolen")
("synchronization status" "synchronisatiestatus")
("synchronize" "synchroniseren")
("synchronize bibliographic references" "bibliografische referenties synchroniseren")
("synchronize file or directory" "bestand of map synchroniseren")
("synchronize with remote server" "synchroniseren met externe server")
("synopsis" "synopsis")
("system command" "systeem kommando")
("system environment variables" "primitieve omgevingsvariabelen")
("tab-completion" "tab-aanvulling")
("tabbed" "met tabs")
("table" "tabel")
("table breaking" "tabelafbraak")
("table command" "tabel kommando")
("table height" "hoogte van tabel")
("table of contents" "inhoudsopgave")
("table properties" "tabeleigenschappen")
("table width" "breedte van tabel")
("tables" "tabellen")
("tabular" "tabuleer")
("tabular material" "tabellen")
("tag" "tag")
("tags with special rendering" "tags met speciale weergave")
("taiwanese" "Taiwanees")
("tangent" "tangens")
("target" "doelwit")
("teXmacs DTD" "teXmacs DTD")
("teXmacs as an interface" "TeXmacs als koppelprogramma")
("teXmacs buffer expected" "teXmacs buffer verwacht")
("teXmacs buffer on disk expected" "teXmacs buffer op schijf verwacht")
("teXmacs database preferences" "teXmacs database voorkeuren")
("teXmacs extensions to scheme and utilities" "teXmacs-uitbreidingen voor schema en hulpprogramma's")
("teXmacs fonts" "TeXmacs lettertypes")
("teXmacs macro" "teXmacs macro")
("teXmacs manual" "teXmacs handleiding")
("teXmacs manuel" "teXmacs handboek")
("teXmacs notice" "dank aan TeXmacs")
("teXmacs package" "teXmacs-pakket")
("teXmacs plugins" "teXmacs-plug-ins")
("teXmacs primitives" "teXmacs primitieven")
("teXmacs style" "teXmacs-stijl")
("teXmacs style files" "teXmacs stijlbestanden")
("teXmacs website" "teXmacs website")
("teXmacs-related work" "werk omtrent TeXmacs")
("ternary" "derde")
("test" "test")
("test routine" "testroutine")
("testing tree-view" "boomstructuur testen")
("tex" "tex")
("text" "tekst")
("text borders" "tekstranden")
("text box style" "stijl voor tekstvakken")
("text corners" "teksthoeken")
("text font" "tekst lettertype")
("text for note" "tekst voor de aantekening")
("text height correction" "hoogtekorrektie van tekst")
("text padding" "tekstopvulling")
("text width" "tekst breedte")
("texts" "teksten")
("textual" "tekstueel")
("textual operator" "tekstuele operator")
("textual spreadsheet" "tekstuele spreadsheet")
("textual table" "tabel met tekst")
("th century bc" "de eeuw voor C.")
("th root" "de machts wortel")
("thai" "thais")
("the TeXmacs authors" "de makers van TeXmacs")
("the TeXmacs format" "het TeXmacs formaat")
("the TeXmacs plug-in system" "het TeXmacs plug-in systeem")
("the application did not send its usual startup banner" "de toepassing heeft niet zijn gebruikelijke opstartmelding verzonden")
("the application does not reply" "de toepassing geeft geen antwoord")
("the application is already running" "de toepassing is al bezig")
("the boxes produced by the typesetter" "de door de letterzetter geproduceerde rechthoeken")
("the buffer has not been saved" "de buffer is niet opgeslagen")
("the document has not been saved" "de buffer is niet bewaard")
("the graphical user interface" "de graphische gebruikersinterface")
("the leaves of TeXmacs trees" "de bladeren van TeXmacs bomen")
("the mycas example" "het voorbeeld 'mycas'")
("the primitive TeXmacs constructs" "pritimitieve TeXmacs constructies")
("the standard TeXmacs styles" "de standaard TeXmacs stijlen")
("theme" "thema")
("theme parameters" "themaparameters")
("theorem" "stelling")
("theorems" "stellingen")
("there are unsaved documents" "niet alle bestanden zijn bewaard")
("there are unsaved files" "er zijn niet-opgeslagen bestanden")
("these collected public keys will be definitely lost" "deze verzamelde openbare sleutels zullen zeker verloren gaan")
("these public keys will be definitely lost" "deze openbare sleutels zullen zeker verloren gaan")
("these secret keys will be definitely lost" "deze geheime sleutels zullen zeker verloren gaan")
("thicken" "verdik")
("thickness" "dikte")
("thin" "dun")
("third" "derde")
("this" "dit")
("this article has been written using" "dit artikel is geschreven met")
("this buffer has not been saved" "deze buffer is niet opgeslagen")
("this column" "deze kolom")
("this document has been produced using" "dit document is tot stand gekomen met behulp van")
("this document has been written using" "dit document is geschreven met")
("this document has not been saved" "deze buffer is niet bewaard")
("this line" "deze regel")
("this page" "deze pagina")
("this page footer" "voet voor deze pagina")
("this page header" "kop voor deze pagina")
("this page number" "dit paginanummer")
("this row" "deze rij")
("this style specifies page margins in the TeX way" "deze stijl specificeert paginamarges op de TeX-manier")
("three columns" "drie kolommen")
("three dots" "drie puntjes")
("three times" "drie keer")
("threshold" "drempel")
("through popup windows" "via oppoppende vensters")
("through the menus" "via de menu's")
("thumbnails" "serie van plaatjes")
("tilda" "slangetje")
("tilde" "slangetje")
("time evolution" "tijdsverloop")
("times" "maal")
("timings" "timings")
("tiny" "miniem")
("title" "titel")
("title presentation options" "titel presentatie opties")
("title style" "titelstijl")
("title suffix" "titel-achtervoegsel")
("titled block" "blok met titel")
("to the left" "naar links")
("to the right" "naar rechts")
("today" "vandaag")
("toggle cell wrapping mode" "verander modus voor regelafbraak in cellen")
("toggle here" "hier schakelen")
("toggle name" "naam schakelen")
("toggle numbering" "nummering schakelen")
("toggle off" "uitschakelen")
("toggle on" "inschakelen")
("toggle specification" "specificatie schakelen")
("toggle titled" "titel schakelen")
("tolerant" "tolerant")
("tools" "gereedschap")
("top" "top")
("top baseline" "bovenste richtlijn")
("top border" "bovenrand")
("top cell border" "bovenrand cel")
("top cell padding" "ruimte bovenkant cel")
("top level" "topniveau")
("top margin" "bovenrand")
("top padding" "ruimte boven")
("top table border" "bovenrand tabel")
("top table padding" "ruimte bovenkant tabel")
("topless title" "titel zonder top")
("transform" "transformeren")
("transform cell into subtable" "cel omzetten in subtabel")
("transformations" "transformaties")
("translate" "transleren")
("translate::language" "vertaal")
("translations" "vertalingen")
("translations loaded" "vertalingen geladen")
("transpose" "transposeer")
("traversal" "doorkruising")
("traverse" "doorkruisen")
("tree" "boom")
("triangle" "driehoek")
("triangular list items" "driehoekige lijstitems")
("triangularize" "trianguleer")
("trigonometric" "trigonometrisch")
("trigonometric functions" "goniometrische functies")
("trigonometry" "trigonometrie")
("try to import formulas using LaTeX annotations" "probeer formules te importeren met LaTeX-annotaties")
("tuple" "tupel")
("turkish" "turks")
("turn off" "uitschakelen")
("turn on" "inschakelen")
("turn on wallet" "portemonnee inschakelen")
("tutorial" "inleiding")
("tutorials" "inleidingen")
("twice" "tweemaal")
("two columns" "twee kolommen")
("two dots" "twee punten")
("type" "type")
("type a LaTeX command followed by" "typ een LaTeX-commando gevolgd door")
("type a latex command followed by" "typ een latex kommando in, gevolgd door")
("type a latex command followed by return" "typ een latexcommando gevolgd door return")
("type body" "typ lichaam")
("type denominator" "typ noemer")
("type numerator" "typ teller")
("type script" "typ subscript of exponent")
("typesetted boxes" "geletterzette rechthoeken")
("typewriter" "schrijfmachine")
("typewriter small caps" "schrijfmachine kleine hoofdletters")
("typing a simple text" "simpele tekst intypen")
("typing simple texts" "simpele tekst intypen")
("uTF-8 with inputenc LaTeX package" "uTF-8 met inputenc LaTeX-pakket")
("ugaritic" "ugaritisch")
("ukrainian" "ukraeens")
("ultra compact" "ultracompact")
("unchanged" "ongewijzigd")
("underbrace" "accolade onder")
("underline" "onderstreept")
("underlined" "onderstreept")
("undo" "terug")
("undo last changes" "maak laatste veranderingen ongedaan")
("unevaluated argument" "niet-geëvalueerd argument")
("unevaluated value" "niet-geëvalueerde waarde")
("unextended" "niet uitgebreid")
("unfold" "ontvouwen")
("unfold all" "alles ontvouwen")
("unfold all fields" "alle velden ontvouwen")
("unfolded" "uitgevouwen")
("ungroup" "ontbinden")
("unit" "eenheid")
("unit length" "lengte van eenheid")
("unknown secret key fingerprint" "onbekende geheime sleutel vingerafdruk")
("unpublished" "niet gepubliceerd")
("unregistered file" "niet-geregistreerd bestand")
("unroll" "uitrollen")
("unsecure script refused" "onveilige script geweigerd")
("unsupported link mode" "niet ondersteunde linkmodus")
("until" "tot")
("untitled block" "naamloos blok")
("up" "omhoog")
("up to date" "actueel")
("update" "actualiseer")
("update buffer" "buffer bijwerken")
("update from web" "haal nieuwe documentatie van het web")
("update image links" "aktualiseer verbonden plaatjes")
("update remote ssh connection" "ssh-verbinding actualiseren")
("update this buffer" "deze buffer bijwerken")
("update web site" "website bijwerken")
("upight" "rechtop")
("upload" "upload")
("upload file or directory" "bestand of map uploaden")
("upper border" "bovenrand")
("upright" "rechtop")
("upwards" "omhoog")
("url" "url")
("use CSS for more advanced formatting" "CSS gebruiken voor meer geavanceerde opmaak")
("use Inkscape for conversion from SVG" "gebruik Inkscape voor conversie van SVG")
("use MathML" "gebruik MathML")
("use TeXmacs" "gebruik TeXmacs")
("use a black color" "gebruik zwarte kleur")
("use a blue color" "gebruik blauwe kleur")
("use a bold font" "gebruik een vet lettertype")
("use a brown color" "gebruik bruine kleur")
("use a calligraphic font" "gebruik een kalligrafisch lettertype")
("use a green color" "gebruik groene kleur")
("use a grey color" "gebruik grey kleur")
("use a magenta color" "gebruik paarse kleur")
("use a orange color" "gebruik oranje kleur")
("use a pink color" "gebruik roze kleur")
("use a red color" "gebruik rode kleur")
("use a sans serif font" "gebruik een schreefloos lettertype")
("use a typewriter font" "gebruik een lettertype van een schrijfmachine")
("use a white color" "gebruik witte kleur")
("use a yellow color" "gebruik gele kleur")
("use as master" "gebruik als master")
("use blackboard bold font" "gebruik schoolbord letters")
("use bold font series" "gebruik vette letters")
("use calligraphical font" "gebruik kalligrafische letters")
("use custom note symbol" "gebruik aangepaste notitiesymbool")
("use extensible brackets" "gebruik uitschuifbare beugels")
("use footnote font size" "gebruik erg kleine letters")
("use fraktur font" "gebruik Gotische letters")
("use high resolution fonts" "gebruik hoge resolutie lettertypen")
("use high resolution icons" "gebruik iconen met hoge resolutie")
("use huge font size" "gebruik enorm grote letters")
("use italic font shape" "gebruik shuine letters")
("use large font size" "gebruik grote letters")
("use left hand column as border" "gebruik kolom links als rand")
("use line wrapping for lines which are longer than 80 characters" "gebruik regelafbraak voor regels die langer zijn dan 80 tekens")
("use margin kerning (protrusion)" "gebruik overhang in de kantlijn")
("use medium font series" "gebruik gewone letterdikte")
("use normal font size" "gebruik normale lettergrootte")
("use package" "gebruik pakket")
("use paragraph width" "gebruik alineabreedte")
("use print dialogue" "printdialoog gebruiken")
("use protrusion" "gebruik overhang in de kantlijn")
("use really huge font size" "gebruik echt enorme letters")
("use relative path" "gebruik relatief pad")
("use retina fonts" "gebruik retina-lettertypen")
("use retina icons" "gebruik retina-iconen")
("use right font shape" "gebruik rechte letters")
("use right hand column as border" "gebruik kolom rechts als rand")
("use roman font family" "gebruik roman lettertype")
("use row above as border" "gebruik rij hierboven als rand")
("use row below as border" "gebruik rij hierbeneden als rand")
("use sans serif font family" "gebruik schreefloos lettertype")
("use script font size" "gebruik erg kleine letters")
("use slanted font shape" "gebruik scheve letters")
("use small capitals" "gebruik kleine hoofdletters")
("use small font size" "gebruik kleine letters")
("use small-caps font shape" "gebruik kleine hoofdletters")
("use the blackboard bold font" "gebruik het vette schoolbord lettertype")
("use the fraktur font" "gebruig het fraktur lettertype")
("use tiny font font size" "gebruik minieme letters")
("use typewriter font family" "gebruik schrijfmachine lettertype")
("use unified toolbars" "verenig titelbalk en bovenste werkbalk")
("use very large font size" "gebruik erg grote letters")
("user interface" "gebruikersinterface")
("user interface language" "taal voor de gebruikersinterface")
("user interface theme" "thema voor de gebruikersinterface")
("user manual" "gebruikersboek")
("user preferences" "gebruikersvoorkeuren")
("user provided icons" "gebruikers gedefiniëerde iconen")
("users of Cyrillic languages" "gebruikers van Cyrillische talen")
("users of oriental languages" "gebruikers van oosterse talen")
("utf-8 with inputenc" "utf-8 met inputenc")
("utf-8 with inputenc LaTeX package" "utf-8 met inputenc LaTeX-pakket")
("utilities" "hulpprogramma's")
("value" "waarde")
("vanish" "verdwijnen")
("variable" "variabele")
("variant" "variant")
("vector" "vektor")
("verbatim" "woordelijk")
("verbose" "uitgebreid")
("verse" "vers")
("version" "versie")
("versioning tool" "gereedschap voor versiecontrole")
("vertical" "vertikaal")
("vertical after" "vertikaal achteraan")
("vertical alignment" "vertikale plaatsing")
("vertical before" "vertikaal vooraan")
("vertical cell alignment" "vertikale plaatsing in cel")
("vertical margins" "verticale marges")
("vertical padding" "verticale vulling")
("vertical part" "vertikaal deel")
("vertical position" "vertikale positie")
("vertical space" "vertikale spatie")
("vertical space after" "verticale ruimte hierna")
("vertical space before" "verticale ruimte hiervoor")
("vertical space stretchability" "verticale rekbaarheid")
("vertical table alignment" "vertikale plaatsing tabel")
("vertically align cell to the base" "plaats inhoud cel vertikaal via richtlijn")
("vertically center the cell" "centreer inhoud cel vertikaal")
("very large" "erg groot")
("very small" "erg klein")
("vietnamese" "vietnamees")
("view" "venster")
("visible" "zichtbaar")
("visible except here" "zichtbaar behalve hier")
("visible from here on" "zichtbaar vanaf hier")
("visible only here" "alleen hier zichtbaar")
("visible until here" "zichtbaar tot hier")
("visited color" "kleur van bezochte verwijzigingen")
("visited loci" "bezochte loci")
("volume" "volume")
("wallet" "portemonnee")
("warning" "waarschuwing")
("warnings" "waarschuwingen")
("wave" "golf")
("wave length x" "golflengte x")
("wave length y" "golflengte y")
("web" "web")
("weight" "dikte")
("welcome" "welkom")
("welcome to GNU TeXmacs" "welkom tot GNU TeXmacs")
("what is new" "nieuwigheden")
("when finished" "zodra klaar")
("when line wrapping" "bij gebruik van regelafbraak")
("when wrapping" "bij gebruik van regelafbraak")
("while" "zolang")
("white" "wit")
("whitespace" "lege ruimte")
("wide" "breed")
("wide accent" "breed accent")
("wide bar" "brede streep")
("wide block" "breed blok")
("wide colored" "breed gekleurd")
("wide float" "breed zwevend object")
("wide footnote" "brede voetnoot")
("wide note" "brede aantekening")
("wide tabular" "brede tabel")
("widescreen" "breedbeeld")
("width" "breedte")
("width is exactly the specified width" "gebruik gespecifieerde breedte")
("width is maximum of specified width and box width" "gebruik maximum van gespecifieerde breedte en breedte van inhoud")
("width is minimum of specified width and box width" "gebruik minimum van gespecifieerde breedte en breedte van inhoud")
("width magnification" "vergroting breedte")
("window" "venster")
("windows" "vensters")
("window height" "venster hoogte")
("window width" "venster breedte")
("windows key" "windows toets")
("with" "met")
("with newer version" "met nieuwere versie")
("with older version" "met oudere versie")
("wood" "hout")
("word count" "aantal woorden")
("wrap lines" "regels afbreken")
("write a macro" "schrijf een macro")
("write a name" "schrijf een naam")
("write bold mathematics" "schrijf vette wiskunde")
("write bold text" "schrijf vette tekst")
("write italic text" "schrijf schuine tekst")
("write sample text" "schrijf voorbeeld tekst")
("write strong text" "schrijf belangrijke tekst")
("write typewriter text" "schrijf typmachine tekst")
("write verbatim text" "schrijf woordelijke tekst")
("writing TeXmacs bibliography styles" "creatie van bibliografische stijlen voor TeXmacs")
("writing data converters" "schrijf data converters")
("writing documentation" "documentatie schrijven")
("writing your own style files" "scrijf uw eigen stijlbestanden")
("written with TeXmacs" "geschreven met TeXmacs")
("wrong empty passphrase" "verkeerde lege wachtzin")
("wrong passphrase" "verkeerde wachtzin")
("year" "jaar")
("year, Name" "jaar, naam")
("yellow" "geel")
("yes" "ja")
("you are attempting to open an encrypted file while" "u probeert een gecodeerd bestand te openen terwijl")
("you can also obtain" "u kunt")
("you might consider enabling the experimental" "te overwegen is het inschakelen van experimentele")
("you must add a bibliography file" "u moet een bibliografiebestand toevoegen")
("you should also make sure that GnuPG is installed" "u moet er ook voor zorgen dat GnuPG is geïnstalleerd")
("your document is back in its original state" "Uw document is terug in zijn originele toestand")
("your first interface" "uw eerste interface")
("your language" "uw taal")
("your personal dictionary has been modified" "uw persoonlijke woordenboek is aangepast")
("zebra" "zebra")
("zigzag" "zigzag")
("zoom" "zoom")
("zoom factor" "zoomfactor")
("zoom in" "inzoomen")
("zoom out" "uitzoomen")
("zoom/unzoom objects" "objecten inzoomen/uitzoemen")
